PRINT 'CREATENEWTABLES ------- BEGIN'

CREATE TABLE [dbo].[TT_TaskAssignee] (
	[TaskAssigneeID] [int] IDENTITY (1, 1) NOT NULL ,
	[TaskID] [int] NOT NULL ,
	[UserID] [int] NOT NULL 
) ON [PRIMARY]

GO

ALTER TABLE [dbo].[TT_TaskAssignee] WITH NOCHECK ADD 
	CONSTRAINT [PK_TT_TaskAssignee] PRIMARY KEY  CLUSTERED 
	(
		[TaskAssigneeID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[TT_TaskAssignee] WITH NOCHECK ADD 
	CONSTRAINT [IX_TT_TaskAssignee] UNIQUE  NONCLUSTERED 
	(
		[TaskID],
		[UserID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[TT_TaskAssignee] ADD 
	CONSTRAINT [FK_TT_TaskAssignee_TT_Tasks] FOREIGN KEY 
	(
		[TaskID]
	) REFERENCES [dbo].[TT_Tasks] (
		[TaskID]
	) ON DELETE CASCADE ,
	CONSTRAINT [FK_TT_TaskAssignee_TT_Users] FOREIGN KEY 
	(
		[UserID]
	) REFERENCES [dbo].[TT_Users] (
		[UserID]
	)
GO

PRINT 'CREATENEWTABLES ------- END'

PRINT 'SETUPMULTIASSIGN ------- BEGIN'

DECLARE @taskid int,
	@userid int
	
DECLARE taskcur CURSOR FOR
	SELECT TaskID, AssignedTo FROM TT_Tasks

OPEN taskcur
FETCH NEXT FROM taskcur INTO @taskid, @userid

WHILE @@FETCH_STATUS = 0
BEGIN
	INSERT INTO TT_TaskAssignee(TaskID, UserID)
		VALUES(@taskid, @userid)
		
	FETCH NEXT FROM taskcur INTO @taskid, @userid
END

CLOSE taskcur
DEALLOCATE taskcur
GO

ALTER TABLE TT_Bugs DROP COLUMN AssignedTo
GO

ALTER TABLE TT_Tasks DROP COLUMN AssignedTo
GO
PRINT 'SETUPMULTIASSIGN ------- END'

PRINT 'CREATEDEFDATA ------- BEGIN'
/*
	create tables with default data
*/
CREATE TABLE [dbo].[DD_Priorities] (
	[ID] [int] IDENTITY (1, 1) NOT NULL ,
	[Number] [int] NOT NULL ,
	[Name] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL 
) ON [PRIMARY]
GO

ALTER TABLE [dbo].[DD_Priorities] WITH NOCHECK ADD 
	CONSTRAINT [PK_DD_Priorities] PRIMARY KEY  CLUSTERED 
	(
		[ID]
	)  ON [PRIMARY] 
GO

INSERT INTO DD_Priorities (Number, Name)
VALUES (1,'Urgent')

GO

INSERT INTO DD_Priorities (Number, Name)
VALUES (2,'High')

GO

INSERT INTO DD_Priorities (Number, Name)
VALUES (3,'Medium')

GO

INSERT INTO DD_Priorities (Number, Name)
VALUES (4,'Low')
GO

CREATE TABLE [dbo].[DD_Statuses] (
	[ID] [int] IDENTITY (1, 1) NOT NULL ,
	[StatusName] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Number] [int] NOT NULL ,
	[StatusType] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL 
) ON [PRIMARY]
GO

ALTER TABLE [dbo].[DD_Statuses] WITH NOCHECK ADD 
	CONSTRAINT [PK_DD_Statuses] PRIMARY KEY  CLUSTERED 
	(
		[ID]
	)  ON [PRIMARY] 
GO

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Hold',1,'Task')
GO

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Development',2,'Task')
GO

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Testing',3,'Task')
GO

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Completed',4,'Task')
GO

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Assigned',5,'Task')
GO

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Open',1,'Bug')
GO

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Reviewed',2,'Bug')
GO

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Hold',3,'Bug')
GO

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Assigned',4,'Bug')
GO

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Fixed',5,'Bug')
GO

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Closed',6,'Bug')
GO

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Verified & Closed',7,'Bug')
GO

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Submitted',1,'Request')
GO

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Assigned',2,'Request')
GO

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('On Hold',3,'Request')
GO

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Completed',4,'Request')
GO

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Cancelled',5,'Request')
GO

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Open',1,'Project')
GO

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Completed',2,'Project')
GO

CREATE TABLE [dbo].[DD_Categories] (
	[ID] [int] IDENTITY (1, 1) NOT NULL ,
	[Name] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Abbreviation] [nvarchar] (4) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[EstDuration] [decimal](18, 0) NULL 
) ON [PRIMARY]
GO

ALTER TABLE [dbo].[DD_Categories] WITH NOCHECK ADD 
	CONSTRAINT [PK_DD_Categories] PRIMARY KEY  CLUSTERED 
	(
		[ID]
	)  ON [PRIMARY] 
GO

INSERT INTO DD_Categories (Name, Abbreviation, EstDuration)
VALUES ('Development','dev',200)
GO

INSERT INTO DD_Categories (Name, Abbreviation, EstDuration)
VALUES ('QA','qa',200)
GO

INSERT INTO DD_Categories (Name, Abbreviation, EstDuration)
VALUES ('Troubleshooting','trbs',200)
GO

CREATE TABLE [dbo].[DD_BugTypes] (
	[ID] [int] IDENTITY (1, 1) NOT NULL ,
	[Number] [int] NOT NULL ,
	[Name] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL 
) ON [PRIMARY]
GO

ALTER TABLE [dbo].[DD_BugTypes] WITH NOCHECK ADD 
	CONSTRAINT [PK_DD_BugTypes] PRIMARY KEY  CLUSTERED 
	(
		[ID]
	)  ON [PRIMARY] 
GO

INSERT INTO DD_BugTypes (Number, Name)
VALUES (1,'Interface')
GO

INSERT INTO DD_BugTypes (Number, Name)
VALUES (2,'Misspelling')
GO

INSERT INTO DD_BugTypes (Number, Name)
VALUES (3,'Design')
GO

INSERT INTO DD_BugTypes (Number, Name)
VALUES (4,'Functionality')
GO

INSERT INTO DD_BugTypes (Number, Name)
VALUES (5,'Logic')
GO

INSERT INTO DD_BugTypes (Number, Name)
VALUES (6,'Calculation')
GO
PRINT 'CREATEDEFDATA ------- END'

/*
	upgrade message board - add a ProjectID field
*/

PRINT 'ADDPROJTOMSGBOARD ------- BEGIN'
ALTER TABLE TT_MessageBoard ADD ProjectID int NULL
GO

DECLARE @parid int, @partype int, @msgid int
DECLARE @projID int

DECLARE msgcur CURSOR FOR
SELECT MessageID, ParentID, ParentType FROM TT_MessageBoard

OPEN msgcur
FETCH NEXT FROM msgcur into @msgid, @parid, @partype

WHILE @@FETCH_STATUS = 0
BEGIN

	SET @projid = 0	
	
	-- message for a task 
	IF @partype=1 
		SET @projid = (SELECT ProjectID FROM TT_Tasks WHERE TaskID = @parid)

	-- message for a bug
	IF @partype=2 
		SET @projid = (SELECT ProjectID FROM TT_Bugs WHERE BugID = @parid)
	
	-- message for a request
	IF @partype=3 
		SET @projid = (SELECT ProjectID FROM TT_Requests WHERE ReqID = @parid)
	
	IF @projid <> 0 
		UPDATE TT_MessageBoard SET ProjectID = @projid WHERE MessageID = @msgid
		
	FETCH NEXT FROM msgcur into @msgid, @parid, @partype
END

CLOSE msgcur
DEALLOCATE msgcur
GO

-- delete message for already removed projects
DELETE FROM TT_MessageBoard WHERE ProjectID IS NULL

-- introduce a new constraint to automatically remove
-- messages when a project is removed
ALTER TABLE TT_MessageBoard ADD
	CONSTRAINT [FK_TT_MessageBoard_TT_Projects] FOREIGN KEY 
		(
			[ProjectID]
		) REFERENCES [TT_Projects] (
			[ProjectID]
		) ON DELETE CASCADE 
GO

PRINT 'ADDPROJTOMSGBOARD ------- END'

PRINT 'MISC ------- BEGIN'
/*
	upgrade UserOptions - add a ShowWflHistory field
*/

ALTER TABLE TT_UserOps ADD ShowWflHistory bit
GO

UPDATE TT_UserOps SET ShowWflHistory=1

/*
	upgrade TT_Projects - remove ManagerUserID field and the associated
	constraint
*/
IF EXISTS(SELECT name FROM sysobjects WHERE name='FK_Projects_Users' AND xtype='F')
	ALTER TABLE TT_Projects DROP CONSTRAINT FK_Projects_Users
	
GO

ALTER TABLE TT_Projects DROP COLUMN ManagerUserID
GO

/*
	fix issues with old databases. 2 contraints should be removed
*/
IF EXISTS(SELECT name FROM sysobjects WHERE name='FK_EntryLog_Categories' AND xtype='F')
	ALTER TABLE TT_EntryLog DROP CONSTRAINT FK_EntryLog_Categories
GO

IF EXISTS(SELECT name FROM sysobjects WHERE name='FK_TT_Tasks_TT_Categories' AND xtype='F')
	ALTER TABLE TT_Tasks DROP CONSTRAINT FK_TT_Tasks_TT_Categories
GO

/*
	upgrade TT_Tasks - add a StartDate field
*/
ALTER TABLE TT_Tasks ADD StartDate datetime NULL	

/*
	upgrade TT_Projects and TT_Tasks - add a PercentCompleted field
*/
ALTER TABLE TT_Projects ADD PercentCompleted int NULL
GO

ALTER TABLE TT_Tasks ADD PercentCompleted int NULL
GO

/*
	upgrade TT_Tasks - add a Priority field
*/
ALTER TABLE TT_Tasks ADD Priority int NULL
GO
PRINT 'MISC ------- END'

PRINT 'REPGEN ------- BEGIN'
/* 
	report generator DB structure 
*/
CREATE TABLE [dbo].[RG_Datasource] (
	[DatasourceID] [int] IDENTITY (1, 1) NOT NULL ,
	[Name] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[QueryText] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	[InternalID] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

CREATE TABLE [dbo].[RG_DatasourceField] (
	[DatasourceFieldID] [int] IDENTITY (1, 1) NOT NULL ,
	[DatasourceID] [int] NOT NULL ,
	[FieldName] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[DisplayName] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Datatype] [int] NULL ,
	[DataFormat] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[Width] [int] NULL ,
	[Aggregation] [int] NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[RG_DatasourceParam] (
	[DatasourceParamID] [int] IDENTITY (1, 1) NOT NULL ,
	[DatasourceID] [int] NOT NULL ,
	[ParamName] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[DisplayName] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
	[Internal] [bit] NOT NULL,
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[RG_Group] (
	[GroupID] [int] IDENTITY (1, 1) NOT NULL ,
	[TemplateID] [int] NOT NULL ,
	[HeaderXML] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[FooterXML] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL 
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

CREATE TABLE [dbo].[RG_GroupField] (
	[GroupFieldID] [int] IDENTITY (1, 1) NOT NULL ,
	[GroupID] [int] NOT NULL ,
	[DatasourceFieldID] [int] NOT NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[RG_GroupFieldAgg] (
	[GroupFieldAggID] [int] IDENTITY (1, 1) NOT NULL ,
	[GroupID] [int] NOT NULL ,
	[TemplateFieldID] [int] NOT NULL ,
	[AggregationType] [int] NOT NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[RG_Template] (
	[TemplateID] [int] IDENTITY (1, 1) NOT NULL ,
	[DatasourceID] [int] NOT NULL ,
	[Name] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[HeaderXML] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[FooterXML] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[ColumnHeaderXML] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[PageHeaderXML] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[PageFooterXML] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL 
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

CREATE TABLE [dbo].[RG_TemplateField] (
	[TemplateFieldID] [int] IDENTITY (1, 1) NOT NULL ,
	[TemplateID] [int] NOT NULL ,
	[DatasourceFieldID] [int] NULL ,
	[FieldName] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[DisplayName] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Datatype] [int] NULL ,
	[DataFormat] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[Width] [decimal](5, 0) NOT NULL ,
	[Expression] [varchar] (1000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[SortOrder] [int] NULL ,
	[SortDirection] [int] NULL ,
	[DefaultFilter] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[FontName] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[FontSize] [int] NOT NULL ,
	[FontFlags] [varchar] (10) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[Align] [int] NULL 
) ON [PRIMARY] 
GO

ALTER TABLE [dbo].[RG_Datasource] WITH NOCHECK ADD 
	CONSTRAINT [PK_RG_DataSource] PRIMARY KEY  CLUSTERED 
	(
		[DatasourceID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[RG_DatasourceField] WITH NOCHECK ADD 
	CONSTRAINT [PK_RG_DataSourceField] PRIMARY KEY  CLUSTERED 
	(
		[DatasourceFieldID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[RG_DatasourceParam] WITH NOCHECK ADD 
	CONSTRAINT [PK_RG_DataSourceParam] PRIMARY KEY  CLUSTERED 
	(
		[DatasourceParamID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[RG_Group] WITH NOCHECK ADD 
	CONSTRAINT [PK_RG_TemplateGroup] PRIMARY KEY  CLUSTERED 
	(
		[GroupID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[RG_GroupField] WITH NOCHECK ADD 
	CONSTRAINT [PK_RG_TemplateGroupField] PRIMARY KEY  CLUSTERED 
	(
		[GroupFieldID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[RG_GroupFieldAgg] WITH NOCHECK ADD 
	CONSTRAINT [PK_RG_GroupFieldAgg] PRIMARY KEY  CLUSTERED 
	(
		[GroupFieldAggID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[RG_Template] WITH NOCHECK ADD 
	CONSTRAINT [PK_RG_Template] PRIMARY KEY  CLUSTERED 
	(
		[TemplateID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[RG_TemplateField] WITH NOCHECK ADD 
	CONSTRAINT [PK_RG_TemplateField] PRIMARY KEY  CLUSTERED 
	(
		[TemplateFieldID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[RG_TemplateField] WITH NOCHECK ADD 
	CONSTRAINT [DF_RG_TemplateField_FontSize] DEFAULT (10) FOR [FontSize]
GO

ALTER TABLE [dbo].[RG_DatasourceField] ADD 
	CONSTRAINT [FK_RG_DataSourceField_RG_DataSource] FOREIGN KEY 
	(
		[DatasourceID]
	) REFERENCES [dbo].[RG_Datasource] (
		[DatasourceID]
	) ON DELETE CASCADE  ON UPDATE CASCADE 
GO

ALTER TABLE [dbo].[RG_DatasourceParam] ADD 
	CONSTRAINT [FK_RG_DataSourceParam_RG_DataSource] FOREIGN KEY 
	(
		[DatasourceID]
	) REFERENCES [dbo].[RG_Datasource] (
		[DatasourceID]
	) ON DELETE CASCADE  ON UPDATE CASCADE 
GO

ALTER TABLE [dbo].[RG_Group] ADD 
	CONSTRAINT [FK_RG_TemplateGroup_RG_Template] FOREIGN KEY 
	(
		[TemplateID]
	) REFERENCES [dbo].[RG_Template] (
		[TemplateID]
	) ON DELETE CASCADE  ON UPDATE CASCADE 
GO

ALTER TABLE [dbo].[RG_GroupField] ADD 
	CONSTRAINT [FK_RG_GroupField_RG_DatasourceField] FOREIGN KEY 
	(
		[DatasourceFieldID]
	) REFERENCES [dbo].[RG_DatasourceField] (
		[DatasourceFieldID]
	) ON DELETE CASCADE ,
	CONSTRAINT [FK_RG_GroupField_RG_Group] FOREIGN KEY 
	(
		[GroupID]
	) REFERENCES [dbo].[RG_Group] (
		[GroupID]
	) ON DELETE CASCADE  ON UPDATE CASCADE 
GO

ALTER TABLE [dbo].[RG_GroupFieldAgg] ADD 
	CONSTRAINT [FK_RG_GroupFieldAgg_RG_Group] FOREIGN KEY 
	(
		[GroupID]
	) REFERENCES [dbo].[RG_Group] (
		[GroupID]
	) ON DELETE CASCADE  ON UPDATE CASCADE ,
	CONSTRAINT [FK_RG_GroupFieldAgg_RG_TemplateField] FOREIGN KEY 
	(
		[TemplateFieldID]
	) REFERENCES [dbo].[RG_TemplateField] (
		[TemplateFieldID]
	)
GO

ALTER TABLE [dbo].[RG_Template] ADD 
	CONSTRAINT [FK_RG_Template_RG_DataSource] FOREIGN KEY 
	(
		[DatasourceID]
	) REFERENCES [dbo].[RG_Datasource] (
		[DatasourceID]
	)
GO

ALTER TABLE [dbo].[RG_TemplateField] ADD 
	CONSTRAINT [FK_RG_TemplateField_RG_DataSourceField] FOREIGN KEY 
	(
		[DatasourceFieldID]
	) REFERENCES [dbo].[RG_DatasourceField] (
		[DatasourceFieldID]
	) ON DELETE CASCADE ,
	CONSTRAINT [FK_RG_TemplateField_RG_Template] FOREIGN KEY 
	(
		[TemplateID]
	) REFERENCES [dbo].[RG_Template] (
		[TemplateID]
	) ON DELETE CASCADE  ON UPDATE CASCADE 
GO

/* 
	end report generator structure 
*/

-- BEGINNING TRANSACTION DATA

SET NOCOUNT ON

exec sp_MSforeachtable 'ALTER TABLE ? NOCHECK CONSTRAINT ALL'

exec sp_MSforeachtable 'ALTER TABLE ? DISABLE TRIGGER ALL'

DELETE FROM [dbo].[RG_Datasource]

DELETE FROM [dbo].[RG_DatasourceField]

/* Insert scripts for table: [dbo].[RG_DatasourceField] */

SET IDENTITY_INSERT [dbo].[RG_DatasourceField] ON

INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (1, 1, 'ProjectID', 'ID', 0, '', 15, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (2, 1, 'Name', 'Project Name', 2, '', 30, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (3, 1, 'Description', 'Project Description', 2, '', 30, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (4, 1, 'EstCompletionDate', 'Estimated completion date', 3, '{0:d}', 15, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (8, 1, 'CreationDate', 'Creation date', 3, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (9, 1, 'EstDuration', 'Estimated duration', 1, '', 10, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (10, 1, 'StatusName', 'Status', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (11, 1, 'Priority', 'Priority', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (153, 2, 'TaskID', 'ID', 0, '', 10, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (154, 2, 'Description', 'Description', 2, '', 30, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (158, 2, 'StartDate', 'Start date', 3, '{0:d}', 15, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (159, 2, 'EstCompletionDate', 'Estimated completion date', 3, '{0:d}', 15, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (160, 2, 'EstDuration', 'Estimated duration', 1, '', 15, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (162, 2, 'Title', 'Title', 2, '', 30, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (167, 2, 'ProjectName', 'Project', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (168, 2, 'StatusName', 'Status', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (169, 2, 'CategoryName', 'Category', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (170, 4, 'BugID', 'ID', 0, '', 10, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (172, 4, 'Description', 'Description', 2, '', 30, 0)
-- << vp 07/04/05: changed to fix bug when priorities were displayed as numbers
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (175, 4, 'PriorityName', 'Priority', 2, '', 10, 0)
-- >> end change
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (176, 4, 'DateOpened', 'Opened', 3, '', 15, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (181, 4, 'Summary', 'Summary', 2, '', 30, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (182, 4, 'ProjectName', 'Project', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (183, 4, 'OpenedByDisplayName', 'Opened by', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (184, 4, 'BugTypeName', 'Type', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (185, 4, 'StatusName', 'Status', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (186, 5, 'ReqID', 'ID', 0, '', 10, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (188, 5, 'Description', 'Description', 2, '', 30, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (191, 5, 'DateEntered', 'Submitted', 3, '', 15, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (193, 5, 'Summary', 'Summary', 2, '', 30, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (194, 5, 'ProjectName', 'Project', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (195, 5, 'StatusName', 'Status', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (196, 6, 'EntryLogID', 'EntryLogID', 0, '', 5, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (197, 6, 'Description', 'Description', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (198, 6, 'Duration', 'Duration', 1, '', 5, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (199, 6, 'EntryDate', 'Date', 3, '{0:d}', 10, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (204, 6, 'Billable', 'Billable', 2, '', 5, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (205, 6, 'ProjectName', 'Project', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (206, 6, 'UserDisplayName', 'Entered By', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (207, 6, 'TaskTitle', 'Task', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (208, 6, 'CategoryName', 'Category', 2, '', 20, 0)

SET IDENTITY_INSERT [dbo].[RG_DatasourceField] OFF

SET IDENTITY_INSERT [dbo].[RG_DatasourceParam] ON

INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (1, 1, 'ProjectIDs', 'ProjectIDs',1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (2, 2, 'AllItemsProjectIDs', 'AllItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (3, 2, 'OwnItemsProjectIDs', 'OwnItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (4, 2, 'QueryUserID', 'AllItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (5, 4, 'AllItemsProjectIDs', 'AllItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (6, 4, 'OwnItemsProjectIDs', 'OwnItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (7, 4, 'QueryUserID', 'AllItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (8, 5, 'AllItemsProjectIDs', 'AllItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (9, 5, 'OwnItemsProjectIDs', 'OwnItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (10, 5, 'QueryUserID', 'AllItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (11, 6, 'AllItemsProjectIDs', 'AllItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (12, 6, 'OwnItemsProjectIDs', 'OwnItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (13, 6, 'QueryUserID', 'AllItemsProjectIDs' ,1)

SET IDENTITY_INSERT [dbo].[RG_DatasourceParam] OFF

SET IDENTITY_INSERT [dbo].[RG_Datasource] ON

INSERT INTO [dbo].[RG_Datasource] ([DatasourceID], [Name], [QueryText], [InternalID]) VALUES (1, 'Projects', 
N'SELECT pj.*, stat.StatusName
FROM TT_Projects pj
INNER JOIN TT_Statuses as stat
ON stat.ProjectID = pj.ProjectID AND stat.Number = pj.Status 
WHERE stat.StatusType=''Project'' AND pj.ProjectID IN ?','projects')
INSERT INTO [dbo].[RG_Datasource] ([DatasourceID], [Name], [QueryText], [InternalID]) VALUES (2, 'Tasks', 
N'SELECT ts.*, proj.Name as ProjectName, stat.StatusName, cat.Name as CategoryName
FROM TT_Tasks ts
INNER JOIN TT_Projects proj
ON proj.ProjectID = ts.ProjectID
INNER JOIN TT_Statuses stat
ON stat.ProjectID = ts.ProjectID AND stat.Number = ts.Status
INNER JOIN TT_Categories cat
ON cat.CategoryID = ts.CategoryID
WHERE stat.StatusType=''Task'' AND proj.ProjectID IN ?
UNION ALL
SELECT ts.*, proj.Name as ProjectName, stat.StatusName, cat.Name as CategoryName
FROM TT_Tasks ts
INNER JOIN TT_Projects proj
ON proj.ProjectID = ts.ProjectID
INNER JOIN TT_Statuses stat
ON stat.ProjectID = ts.ProjectID AND stat.Number = ts.Status
INNER JOIN TT_Categories cat
ON cat.CategoryID = ts.CategoryID
WHERE stat.StatusType=''Task'' AND proj.ProjectID IN ?
AND EXISTS (SELECT * FROM TT_TaskAssignee ta WHERE ta.TaskID = ts.TaskID AND ta.UserID = ?)','tasks')
-- << vp 07/04/05: changed to fix bug when priorities were displayed as numbers
INSERT INTO [dbo].[RG_Datasource] ([DatasourceID], [Name], [QueryText], [InternalID]) VALUES (4, 'Bugs', 
N'SELECT bg.*, proj.Name as ProjectName, usop.DisplayName OpenedByDisplayName, 
bgtp.Name as BugTypeName, stat.StatusName, prio.Name as PriorityName
FROM TT_Bugs bg
INNER JOIN TT_Projects proj
ON proj.ProjectID = bg.ProjectID
INNER JOIN TT_Users usop
ON usop.UserID = bg.OpenedBy
INNER JOIN TT_BugTypes bgtp
ON bgtp.ProjectID = bg.ProjectID AND bgtp.Number = bg.BugType
INNER JOIN TT_Statuses stat
ON stat.ProjectID = bg.ProjectID AND stat.Number = bg.Status 
INNER JOIN TT_Priorities prio
ON prio.Number = bg.Priority AND prio.ProjectID = bg.ProjectID
WHERE stat.StatusType=''Bug'' AND proj.ProjectID in ?
UNION ALL
SELECT bg.*, proj.Name as ProjectName, usop.DisplayName OpenedByDisplayName, 
bgtp.Name as BugTypeName, stat.StatusName, prio.Name as PriorityName
FROM TT_Bugs bg
INNER JOIN TT_Projects proj
ON proj.ProjectID = bg.ProjectID
INNER JOIN TT_Users usop
ON usop.UserID = bg.OpenedBy
INNER JOIN TT_BugTypes bgtp
ON bgtp.ProjectID = bg.ProjectID AND bgtp.Number = bg.BugType
INNER JOIN TT_Statuses stat
ON stat.ProjectID = bg.ProjectID AND stat.Number = bg.Status 
INNER JOIN TT_Priorities prio
ON prio.Number = bg.Priority AND prio.ProjectID = bg.ProjectID
WHERE stat.StatusType=''Bug'' AND proj.ProjectID in ? AND bg.OpenedBy = ?','bugs')
-- >> end change
INSERT INTO [dbo].[RG_Datasource] ([DatasourceID], [Name], [QueryText], [InternalID]) VALUES (5, 'Requests', N'SELECT rq.*, proj.Name as ProjectName, stat.StatusName
FROM TT_Requests rq
INNER JOIN TT_Projects proj
ON proj.ProjectID = rq.ProjectID
INNER JOIN TT_Statuses stat
ON stat.ProjectID = rq.ProjectID AND stat.Number = rq.Status
WHERE stat.StatusType=''Request'' AND proj.ProjectID IN ?
UNION ALL
SELECT rq.*, proj.Name as ProjectName, stat.StatusName
FROM TT_Requests rq
INNER JOIN TT_Projects proj
ON proj.ProjectID = rq.ProjectID
INNER JOIN TT_Statuses stat
ON stat.ProjectID = rq.ProjectID AND stat.Number = rq.Status
WHERE stat.StatusType=''Request'' AND proj.ProjectID IN ? AND
EXISTS (SELECT * FROM TT_Workflow w WHERE w.ObjectType = 4 AND w.ObjectID = rq.ReqID AND w.OwnerID = ?)','requests')
INSERT INTO [dbo].[RG_Datasource] ([DatasourceID], [Name], [QueryText], [InternalID]) VALUES (6, 'Time entries', N'SELECT lg.*, proj.Name as ProjectName, us.DisplayName UserDisplayName, 
ts.Title TaskTitle, cat.Name CategoryName
FROM TT_EntryLog lg
INNER JOIN TT_Projects proj
ON proj.ProjectID = lg.ProjectID
INNER JOIN TT_Users us
ON us.UserID = lg.UserID
INNER JOIN TT_Tasks ts
ON ts.TaskID = lg.TaskID
INNER JOIN TT_Categories cat
ON cat.CategoryID = lg.CategoryID
WHERE proj.ProjectID IN ?
UNION ALL
SELECT lg.*, proj.Name as ProjectName, us.DisplayName UserDisplayName, 
ts.Title TaskTitle, cat.Name CategoryName
FROM TT_EntryLog lg
INNER JOIN TT_Projects proj
ON proj.ProjectID = lg.ProjectID
INNER JOIN TT_Users us
ON us.UserID = lg.UserID
INNER JOIN TT_Tasks ts
ON ts.TaskID = lg.TaskID
INNER JOIN TT_Categories cat
ON cat.CategoryID = lg.CategoryID
WHERE proj.ProjectID IN ? AND lg.UserID = ?', 'timeentries')

SET IDENTITY_INSERT [dbo].[RG_Datasource] OFF

exec sp_MSforeachtable 'ALTER TABLE ? CHECK CONSTRAINT ALL'

exec sp_MSforeachtable 'ALTER TABLE ? ENABLE TRIGGER ALL'

GO
/*
  end report generator datasource data
*/
PRINT 'REPGEN ------- END'

PRINT 'MISC 2 ------- BEGIN'
/*
	Allow null values for EstCompletionDate and EstDuration
*/
ALTER TABLE TT_Projects ALTER COLUMN EstCompletionDate DATETIME NULL
GO

ALTER TABLE TT_Projects ALTER COLUMN EstDuration DECIMAL(10,2) NULL
GO

ALTER TABLE TT_Tasks ALTER COLUMN EstCompletionDate DATETIME NULL
GO

ALTER TABLE TT_Tasks ALTER COLUMN EstDuration DECIMAL(10,2) NULL
GO

/*
	upgrade TT_CustomerDetails - add State field
*/
ALTER TABLE TT_CustomerDetails ADD State varchar(50) NULL
GO

/*
	upgrade TT_Projects - add BugCategoryID and ReqCategotyID fileds
*/
ALTER TABLE TT_Projects ADD BugCategoryID int NULL
GO

ALTER TABLE TT_Projects ADD ReqCategoryID int NULL
GO

PRINT 'MISC 2 ------- END'

PRINT 'FIXUPCATEGORY ------- BEGIN'
-- Update categories for projects
DECLARE projcur CURSOR FOR
	SELECT ProjectID FROM TT_Projects

DECLARE @bugcatID int, @reqcatid int, @projid int

OPEN projcur
FETCH NEXT FROM projcur INTO @projid

WHILE(@@FETCH_STATUS = 0)
BEGIN
	SET @bugcatid = (SELECT CategoryID FROM TT_Categories WHERE ProjectID = @projid AND Abbreviation = 'trbs')
	SET @reqcatid = (SELECT CategoryID FROM TT_Categories WHERE ProjectID = @projid AND Abbreviation = 'dev')

	PRINT '**>'
	PRINT @projid

	IF @bugcatid IS NULL BEGIN
		PRINT 'BUG CAT ID NOT FOUND'
		PRINT 'Adding...'
		INSERT INTO TT_Categories(ProjectID, Name, Abbreviation, EstDuration)
			VALUES(@projid, 'Troubleshooting', 'trbs', 200)
		SET @bugcatid = @@IDENTITY
	END

	IF @reqcatid IS NULL BEGIN
		PRINT 'REQ CAT ID NOT FOUND'
		PRINT 'Adding...'
		INSERT INTO TT_Categories(ProjectID, Name, Abbreviation, EstDuration)
			VALUES(@projid, 'Development', 'dev', 200)
		SET @reqcatid = @@IDENTITY
	END
		
	
	PRINT @bugcatid
	PRINT @reqcatid

	UPDATE TT_Projects SET BugCategoryID = @bugcatid, ReqCategoryID = @reqcatid WHERE ProjectID = @projid
	UPDATE TT_Projects SET PercentCompleted = 0, Priority = 1 WHERE ProjectID = @projid
	PRINT '<**'

	FETCH NEXT FROM projcur INTO @projid
END


CLOSE projcur
DEALLOCATE projcur
PRINT 'FIXUPCATEGORY ------- END'
GO

PRINT 'FIXUPSTARTENDDATE ------- BEGIN'
-- Update percent completed and priorities for tasks
DECLARE curtask CURSOR FOR
	SELECT TaskID FROM TT_Tasks
	
DECLARE @DEFAULT_TASK_START_DATE datetime 
SET @DEFAULT_TASK_START_DATE = GETDATE()

DECLARE @taskid int

OPEN curtask
FETCH NEXT FROM curtask INTO @taskid

WHILE(@@FETCH_STATUS = 0)
BEGIN
	
	UPDATE TT_Tasks SET PercentCompleted = 0, Priority = 1, StartDate = @DEFAULT_TASK_START_DATE WHERE TaskID = @taskid
	
	FETCH NEXT FROM curtask INTO @taskid
END


CLOSE curtask
DEALLOCATE curtask

PRINT 'FIXUPSTARTENDDATE ------- END'
GO

PRINT 'FIXUPTREATASCOMPL ------- BEGIN'
/*
	upgrade DD_Statuses - add a TreatAsCompleted field
*/
ALTER TABLE DD_Statuses ADD TreatAsCompleted BIT NULL
GO

/*
	upgrade TT_Statuses - add a TreatAsCompleted field
*/
ALTER TABLE TT_Statuses ADD TreatAsCompleted BIT NULL	
GO
PRINT 'FIXUPTREATASCOMPL ------- END'

UPDATE TT_Statuses SET TreatAsCompleted = 0
GO

-- Check if Verified & Closed status is present in TT_Statuses
-- and add it if necessary
-- ***************************************
DECLARE statcur CURSOR FOR
	SELECT ProjectID FROM TT_Statuses

DECLARE @projid int
DECLARE @statcount int
DECLARE @freenumber int
DECLARE @statname nvarchar

PRINT 'Adding new status: verified and closed'

OPEN statcur 
FETCH NEXT FROM statcur INTO @projid

WHILE(@@FETCH_STATUS = 0)
BEGIN
	SET @statcount = (SELECT COUNT(StatusID) 
			FROM TT_Statuses 
			WHERE ProjectID = @projid	AND StatusType='Bug' AND Number = 7)
	
	if @statcount = 0
	BEGIN
		PRINT 'Adding new status'
		INSERT INTO TT_Statuses(ProjectID, StatusName, Number, StatusType, TreatAsCompleted)
			VALUES (@projid, 'Verified & Closed', 7, 'Bug', 1)
	END
	ELSE BEGIN
		SET @statcount = (SELECT COUNT(StatusID)
			FROM TT_Statuses 
			WHERE ProjectID = @projid	AND StatusType='Bug' AND StatusName = 'Verified & Closed')

		IF @statcount = 0
		BEGIN
		PRINT 'Number 7 already exists and is not verified and closed. Adding another'

			SET @freenumber = (SELECT MAX(Number) FROM TT_Statuses 
				WHERE ProjectID = @projid AND StatusType='Bug') + 1
				
			INSERT INTO TT_Statuses(ProjectID, StatusName, Number, StatusType, TreatAsCompleted)
				VALUES (@projid, 'Verified & Closed', @freenumber, 'Bug', 1)
		END
	END

	FETCH NEXT FROM statcur INTO @projid			
END

CLOSE statcur
DEALLOCATE statcur
-- ***************************************

GO

-- Update treatAsCompleted field for statuses
DECLARE curstatus CURSOR FOR
	SELECT StatusID FROM TT_Statuses

DECLARE @statusid int

OPEN curstatus
FETCH NEXT FROM curstatus INTO @statusid

WHILE(@@FETCH_STATUS = 0)
BEGIN
	
	UPDATE TT_Statuses SET TreatAsCompleted = 1 WHERE StatusID = @statusid AND Number = 2 AND StatusType='Project'
	UPDATE TT_Statuses SET TreatAsCompleted = 1 WHERE StatusID = @statusid AND Number = 4 AND StatusType='Task'
	UPDATE TT_Statuses SET TreatAsCompleted = 1 WHERE StatusID = @statusid AND Number = 4 AND StatusType='Request'
	UPDATE TT_Statuses SET TreatAsCompleted = 1 WHERE StatusID = @statusid AND Number = 5 AND StatusType='Bug'
	UPDATE TT_Statuses SET TreatAsCompleted = 1 WHERE StatusID = @statusid AND Number = 5 AND StatusType='Request'
	UPDATE TT_Statuses SET TreatAsCompleted = 1 WHERE StatusID = @statusid AND Number = 6 AND StatusType='Bug'
	UPDATE TT_Statuses SET TreatAsCompleted = 1 WHERE StatusID = @statusid AND Number = 7 AND StatusType='Bug'
	
	
	FETCH NEXT FROM curstatus INTO @statusid
END


CLOSE curstatus
DEALLOCATE curstatus

GO

UPDATE DD_Statuses SET TreatAsCompleted = 0
UPDATE DD_Statuses SET TreatAsCompleted = 1 WHERE Number = 2 AND StatusType='Project'
UPDATE DD_Statuses SET TreatAsCompleted = 1 WHERE Number = 4 AND StatusType='Task'
UPDATE DD_Statuses SET TreatAsCompleted = 1 WHERE Number = 4 AND StatusType='Request'
UPDATE DD_Statuses SET TreatAsCompleted = 1 WHERE Number = 5 AND StatusType='Bug'
UPDATE DD_Statuses SET TreatAsCompleted = 1 WHERE Number = 5 AND StatusType='Request'
UPDATE DD_Statuses SET TreatAsCompleted = 1 WHERE Number = 6 AND StatusType='Bug'
UPDATE DD_Statuses SET TreatAsCompleted = 1 WHERE Number = 7 AND StatusType='Bug'

GO

PRINT 'VERSION ------- BEGIN'
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[TT_Version]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
drop table [dbo].[TT_Version]
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[TT_Version]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
 BEGIN
CREATE TABLE [dbo].[TT_Version] (
	[Major] [int] NOT NULL ,
	[Minor] [int] NOT NULL ,
	[Build] [int] NOT NULL 
) ON [PRIMARY]
END

GO
INSERT INTO TT_Version(Major,Minor,Build) VALUES (3,2,2)
PRINT 'VERSION ------- END'