/* 
	Database structure
*/

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE TABLE [dbo].[NF_Notifications] (
	[NotificationID] [int] IDENTITY (1, 1) NOT FOR REPLICATION  NOT NULL ,
	[ProjectID] [int] NOT NULL ,
	[PM] [bit] NOT NULL ,
	[AU] [bit] NOT NULL ,
	[Title] [varchar] (100) COLLATE Cyrillic_General_CI_AS NOT NULL, 
	[Enabled] bit NOT NULL CONSTRAINT DF_NF_Notifications_Enabled DEFAULT 1
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[DD_BugTypes] (
	[ID] [int] IDENTITY (1, 1) NOT NULL ,
	[Number] [int] NOT NULL ,
	[Name] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[DD_Categories] (
	[ID] [int] IDENTITY (1, 1) NOT NULL ,
	[Name] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Abbreviation] [nvarchar] (4) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[EstDuration] [decimal](18, 0) NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[DD_Priorities] (
	[ID] [int] IDENTITY (1, 1) NOT NULL ,
	[Number] [int] NOT NULL ,
	[Name] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[DD_Statuses] (
	[ID] [int] IDENTITY (1, 1) NOT NULL ,
	[StatusName] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Number] [int] NOT NULL ,
	[StatusType] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[TreatAsCompleted] [bit] NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[DD_TaskTypes] (
	[TypeName] [nvarchar] (25) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[ID] [int] NOT NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[MD_Fields] (
	[FieldID] [int] IDENTITY (1, 1) NOT NULL ,
	[EntityID] [int] NOT NULL ,
	[FieldName] [nvarchar] (50) COLLATE Cyrillic_General_CI_AS NOT NULL ,
	[DisplayName] [nvarchar] (50) COLLATE Cyrillic_General_CI_AS NULL ,
	[DataType] [int] NOT NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[NF_Actions] (
	[ActionID] [int] IDENTITY (1, 1) NOT NULL ,
	[Operation] [char] (10) COLLATE Cyrillic_General_CI_AS NOT NULL ,
	[Target] [varchar] (25) COLLATE Cyrillic_General_CI_AS NOT NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[NF_NotificationDetails] (
	[NotificationDetailID] [int] IDENTITY (1, 1) NOT NULL ,
	[NotificationID] [int] NOT NULL ,
	[ActionID] [int] NOT NULL ,
	[Subject] [varchar] (200) COLLATE Cyrillic_General_CI_AS NULL ,
	[Message] [varchar] (500) COLLATE Cyrillic_General_CI_AS NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[NF_NotificationUsers] (
	[NotificationUserID] [int] IDENTITY (1, 1) NOT NULL ,
	[NotificationID] [int] NOT NULL ,
	[UserID] [int] NOT NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[RG_Datasource] (
	[DatasourceID] [int] IDENTITY (1, 1) NOT NULL ,
	[Name] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[QueryText] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[InternalID] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL 
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

CREATE TABLE [dbo].[RG_DatasourceField] (
	[DatasourceFieldID] [int] IDENTITY (1, 1) NOT NULL ,
	[DatasourceID] [int] NOT NULL ,
	[FieldName] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[DisplayName] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Datatype] [int] NULL ,
	[DataFormat] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[Width] [int] NULL ,
	[Aggregation] [int] NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[RG_DatasourceParam] (
	[DatasourceParamID] [int] IDENTITY (1, 1) NOT NULL ,
	[DatasourceID] [int] NOT NULL ,
	[ParamName] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[DisplayName] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Internal] [bit] NOT NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[RG_Group] (
	[GroupID] [int] IDENTITY (1, 1) NOT NULL ,
	[TemplateID] [int] NOT NULL ,
	[HeaderXML] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[FooterXML] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL 
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

CREATE TABLE [dbo].[RG_GroupField] (
	[GroupFieldID] [int] IDENTITY (1, 1) NOT NULL ,
	[GroupID] [int] NOT NULL ,
	[DatasourceFieldID] [int] NOT NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[RG_GroupFieldAgg] (
	[GroupFieldAggID] [int] IDENTITY (1, 1) NOT NULL ,
	[GroupID] [int] NOT NULL ,
	[TemplateFieldID] [int] NOT NULL ,
	[AggregationType] [int] NOT NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[RG_Template] (
	[TemplateID] [int] IDENTITY (1, 1) NOT NULL ,
	[DatasourceID] [int] NOT NULL ,
	[Name] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[HeaderXML] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[FooterXML] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[ColumnHeaderXML] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[PageHeaderXML] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[PageFooterXML] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL 
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

CREATE TABLE [dbo].[RG_TemplateField] (
	[TemplateFieldID] [int] IDENTITY (1, 1) NOT NULL ,
	[TemplateID] [int] NOT NULL ,
	[DatasourceFieldID] [int] NULL ,
	[FieldName] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[DisplayName] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Datatype] [int] NULL ,
	[DataFormat] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[Width] [decimal](5, 0) NOT NULL ,
	[Expression] [varchar] (1000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[SortOrder] [int] NULL ,
	[SortDirection] [int] NULL ,
	[DefaultFilter] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[FontName] [varchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[FontSize] [int] NOT NULL ,
	[FontFlags] [varchar] (10) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[Align] [int] NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[TT_Attach] (
	[AttachID] [int] IDENTITY (1, 1) NOT NULL ,
	[FileName] [nvarchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Type] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Size] [bigint] NOT NULL ,
	[ParentID] [int] NOT NULL ,
	[ParentType] [int] NOT NULL ,
	[FileContents] [image] NULL 
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

CREATE TABLE [dbo].[TT_Categories] (
	[CategoryID] [int] IDENTITY (1, 1) NOT FOR REPLICATION  NOT NULL ,
	[ProjectID] [int] NOT NULL ,
	[Name] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Abbreviation] [nvarchar] (4) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[EstDuration] [decimal](18, 0) NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[TT_CustomerDetails] (
	[CustomerID] [int] IDENTITY (1, 1) NOT NULL ,
	[CompanyName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Address1] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Address2] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[City] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Country] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[ZIP] [nvarchar] (25) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Phone1] [nvarchar] (35) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Phone2] [nvarchar] (35) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[Fax] [nvarchar] (35) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[HourlyRate] [decimal](10, 2) NOT NULL ,
	[Notes] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[State] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[Status] [bit] NULL 
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

CREATE TABLE [dbo].[TT_EntryLog] (
	[EntryLogID] [int] IDENTITY (1, 1) NOT FOR REPLICATION  NOT NULL ,
	[Description] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Duration] [decimal](10, 2) NOT NULL ,
	[EntryDate] [smalldatetime] NOT NULL ,
	[ProjectID] [int] NOT NULL ,
	[UserID] [int] NOT NULL ,
	[CategoryID] [int] NOT NULL ,
	[TaskID] [int] NOT NULL ,
	[Billable] [bit] NULL 
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

CREATE TABLE [dbo].[TT_Expenses] (
	[ExpID] [int] IDENTITY (1, 1) NOT NULL ,
	[ExpType] [int] NOT NULL ,
	[RelID] [int] NOT NULL ,
	[ProjectID] [int] NOT NULL ,
	[ExpDate] [datetime] NOT NULL ,
	[Amount] [decimal](10, 2) NOT NULL ,
	[Description] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL 
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

CREATE TABLE [dbo].[TT_Files] (
	[FileID] [int] IDENTITY (1, 1) NOT NULL ,
	[FileName] [nvarchar] (512) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Description] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Contents] [image] NOT NULL ,
	[IsFolder] [bit] NOT NULL ,
	[ParentID] [int] NOT NULL ,
	[ProjectID] [int] NOT NULL ,
	[StatusChangeDate] [datetime] NOT NULL ,
	[Type] [int] NOT NULL ,
	[UploadedByID] [int] NOT NULL 
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

CREATE TABLE [dbo].[TT_MessageBoard] (
	[MessageID] [int] IDENTITY (1, 1) NOT NULL ,
	[ParentID] [int] NOT NULL ,
	[ParentType] [int] NOT NULL ,
	[PostedBy] [int] NOT NULL ,
	[PostDate] [datetime] NOT NULL ,
	[MessageText] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[ProjectID] [int] NULL 
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

CREATE TABLE [dbo].[TT_Options] (
	[EmailAccount] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[EmailPassword] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[EmailServer] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[FromName] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[FromAddress] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[TT_Payments] (
	[PayID] [int] IDENTITY (1, 1) NOT NULL ,
	[PayType] [int] NOT NULL ,
	[RelID] [int] NOT NULL ,
	[ProjectID] [int] NOT NULL ,
	[PayDate] [datetime] NOT NULL ,
	[Amount] [decimal](10, 2) NOT NULL ,
	[Description] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL 
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

CREATE TABLE [dbo].[TT_ProjectMembers] (
	[ProjectID] [int] NOT NULL ,
	[UserID] [int] NOT NULL ,
	[RoleID] [int] NOT NULL ,
	[Security] [nvarchar] (4000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[MemberID] [int] IDENTITY (1, 1) NOT NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[TT_Projects] (
	[ProjectID] [int] IDENTITY (1, 1) NOT NULL ,
	[Name] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Description] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[EstCompletionDate] [datetime] NULL ,
	[EstDuration] [decimal](10, 2) NULL ,
	[CreationDate] [datetime] NOT NULL ,
	[Status] [int] NOT NULL ,
	[BillingType] [int] NOT NULL ,
	[Amount] [decimal](10, 2) NOT NULL ,
	[IncludeTax] [bit] NOT NULL ,
	[TaxAmount] [decimal](10, 2) NOT NULL ,
	[AutoAssignConfig] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[Priority] [int] NULL ,
	[PercentCompleted] [int] NULL ,
	[BugCategoryID] [int] NULL ,
	[ReqCategoryID] [int] NULL ,
	[CustomerID] [int] NULL 
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

CREATE TABLE [dbo].[TT_Roles] (
	[RoleID] [int] IDENTITY (1, 1) NOT NULL ,
	[Name] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Security] [nvarchar] (4000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[Description] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[HourlyRate] [decimal](10, 2) NOT NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[TT_TaskAssignee] (
	[TaskAssigneeID] [int] IDENTITY (1, 1) NOT NULL ,
	[TaskID] [int] NOT NULL ,
	[UserID] [int] NOT NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[TT_Tasks] (
	[TaskID] [int] IDENTITY (1, 1) NOT FOR REPLICATION  NOT NULL ,
	[Description] [ntext] COLLATE SQL_Latin1_General_CP437_BIN NOT NULL ,
	[ParentID] [int] NOT NULL ,
	[ProjectID] [int] NOT NULL ,
	[Status] [int] NOT NULL ,
	[EstCompletionDate] [datetime] NULL ,
	[EstDuration] [decimal](10, 2) NULL ,
	[CategoryID] [int] NOT NULL ,
	[Title] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Billable] [bit] NOT NULL ,
	[BillType] [int] NOT NULL ,
	[Amount] [decimal](10, 2) NOT NULL ,
	[StartDate] [datetime] NULL ,
	[PercentCompleted] [int] NULL ,
	[Priority] [int] NULL ,
	[TaskType] [int] NULL ,
	[BugType] [int] NULL ,
	[CustomData] [ntext] COLLATE Cyrillic_General_CI_AS NULL 
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

CREATE TABLE [dbo].[TT_UserOps] (
	[OptionID] [int] IDENTITY (1, 1) NOT NULL ,
	[UserID] [int] NOT NULL ,
	[Tooltips] [bit] NOT NULL ,
	[ShowCompletePjs] [bit] NOT NULL ,
	[ShowCompletedTasks] [bit] NULL ,
	[ShowWflHistory] [bit] NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[TT_Users] (
	[DisplayName] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Password] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[UserID] [int] IDENTITY (1, 1) NOT FOR REPLICATION  NOT NULL ,
	[UserName] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[RoleID] [int] NOT NULL ,
	[Email] [nvarchar] (512) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[Enabled] [bit] NOT NULL ,
	[Security] [nvarchar] (4000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[HourlyRate] [decimal](10, 2) NOT NULL ,
	[CustomerID] [int] NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[TT_Version] (
	[Major] [int] NOT NULL ,
	[Minor] [int] NOT NULL ,
	[Build] [int] NOT NULL ,
	[MinorBuild] [int] NOT NULL 
) ON [PRIMARY]
GO

CREATE TABLE [dbo].[TT_Workflow] (
	[WflID] [int] IDENTITY (1, 1) NOT NULL ,
	[Action] [int] NOT NULL ,
	[CustomAction] [int] NOT NULL ,
	[ObjectID] [int] NOT NULL ,
	[ObjectType] [int] NOT NULL ,
	[UserID] [int] NOT NULL ,
	[Description] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
	[EntryDate] [datetime] NOT NULL ,
	[OwnerID] [int] NOT NULL 
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO

ALTER TABLE [dbo].[NF_Notifications] WITH NOCHECK ADD 
	CONSTRAINT [PK_NF_Notifications] PRIMARY KEY  CLUSTERED 
	(
		[NotificationID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[DD_BugTypes] WITH NOCHECK ADD 
	CONSTRAINT [PK_DD_BugTypes] PRIMARY KEY  CLUSTERED 
	(
		[ID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[DD_Categories] WITH NOCHECK ADD 
	CONSTRAINT [PK_DD_Categories] PRIMARY KEY  CLUSTERED 
	(
		[ID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[DD_Priorities] WITH NOCHECK ADD 
	CONSTRAINT [PK_DD_Priorities] PRIMARY KEY  CLUSTERED 
	(
		[ID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[DD_Statuses] WITH NOCHECK ADD 
	CONSTRAINT [PK_DD_Statuses] PRIMARY KEY  CLUSTERED 
	(
		[ID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[MD_Fields] WITH NOCHECK ADD 
	CONSTRAINT [PK_MD_Fields] PRIMARY KEY  CLUSTERED 
	(
		[FieldID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[NF_Actions] WITH NOCHECK ADD 
	CONSTRAINT [PK_NF_Actions] PRIMARY KEY  CLUSTERED 
	(
		[ActionID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[NF_NotificationDetails] WITH NOCHECK ADD 
	CONSTRAINT [PK_NF_NotificationDetails] PRIMARY KEY  CLUSTERED 
	(
		[NotificationDetailID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[NF_NotificationUsers] WITH NOCHECK ADD 
	CONSTRAINT [PK_NF_NotificationUsers] PRIMARY KEY  CLUSTERED 
	(
		[NotificationUserID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[RG_Datasource] WITH NOCHECK ADD 
	CONSTRAINT [PK_RG_DataSource] PRIMARY KEY  CLUSTERED 
	(
		[DatasourceID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[RG_DatasourceField] WITH NOCHECK ADD 
	CONSTRAINT [PK_RG_DataSourceField] PRIMARY KEY  CLUSTERED 
	(
		[DatasourceFieldID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[RG_DatasourceParam] WITH NOCHECK ADD 
	CONSTRAINT [PK_RG_DataSourceParam] PRIMARY KEY  CLUSTERED 
	(
		[DatasourceParamID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[RG_Group] WITH NOCHECK ADD 
	CONSTRAINT [PK_RG_TemplateGroup] PRIMARY KEY  CLUSTERED 
	(
		[GroupID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[RG_GroupField] WITH NOCHECK ADD 
	CONSTRAINT [PK_RG_TemplateGroupField] PRIMARY KEY  CLUSTERED 
	(
		[GroupFieldID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[RG_GroupFieldAgg] WITH NOCHECK ADD 
	CONSTRAINT [PK_RG_GroupFieldAgg] PRIMARY KEY  CLUSTERED 
	(
		[GroupFieldAggID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[RG_Template] WITH NOCHECK ADD 
	CONSTRAINT [PK_RG_Template] PRIMARY KEY  CLUSTERED 
	(
		[TemplateID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[RG_TemplateField] WITH NOCHECK ADD 
	CONSTRAINT [PK_RG_TemplateField] PRIMARY KEY  CLUSTERED 
	(
		[TemplateFieldID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[TT_Attach] WITH NOCHECK ADD 
	CONSTRAINT [PK_TT_Attach] PRIMARY KEY  CLUSTERED 
	(
		[AttachID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[TT_Categories] WITH NOCHECK ADD 
	CONSTRAINT [PK_Categories] PRIMARY KEY  CLUSTERED 
	(
		[CategoryID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[TT_CustomerDetails] WITH NOCHECK ADD 
	CONSTRAINT [PK_TT_CustomerDetails] PRIMARY KEY  CLUSTERED 
	(
		[CustomerID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[TT_Expenses] WITH NOCHECK ADD 
	CONSTRAINT [PK_TT_Expenses] PRIMARY KEY  CLUSTERED 
	(
		[ExpID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[TT_Files] WITH NOCHECK ADD 
	CONSTRAINT [PK_TT_Files] PRIMARY KEY  CLUSTERED 
	(
		[FileID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[TT_MessageBoard] WITH NOCHECK ADD 
	CONSTRAINT [PK_TT_MessageBoard] PRIMARY KEY  CLUSTERED 
	(
		[MessageID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[TT_Payments] WITH NOCHECK ADD 
	CONSTRAINT [PK_TT_Payments] PRIMARY KEY  CLUSTERED 
	(
		[PayID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[TT_ProjectMembers] WITH NOCHECK ADD 
	CONSTRAINT [PK_ProjectMembers] PRIMARY KEY  CLUSTERED 
	(
		[MemberID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[TT_Roles] WITH NOCHECK ADD 
	CONSTRAINT [PK_Roles] PRIMARY KEY  CLUSTERED 
	(
		[RoleID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[TT_TaskAssignee] WITH NOCHECK ADD 
	CONSTRAINT [PK_TT_TaskAssignee] PRIMARY KEY  CLUSTERED 
	(
		[TaskAssigneeID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[TT_Tasks] WITH NOCHECK ADD 
	CONSTRAINT [PK_TT_Tasks] PRIMARY KEY  CLUSTERED 
	(
		[TaskID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[TT_UserOps] WITH NOCHECK ADD 
	CONSTRAINT [PK_TT_UserOps] PRIMARY KEY  CLUSTERED 
	(
		[OptionID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[TT_Workflow] WITH NOCHECK ADD 
	CONSTRAINT [PK_TT_Workflow] PRIMARY KEY  CLUSTERED 
	(
		[WflID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[RG_TemplateField] ADD 
	CONSTRAINT [DF_RG_TemplateField_FontSize] DEFAULT (10) FOR [FontSize]
GO

ALTER TABLE [dbo].[TT_EntryLog] ADD 
	CONSTRAINT [PK_Tasks] PRIMARY KEY  NONCLUSTERED 
	(
		[EntryLogID]
	)  ON [PRIMARY] 
GO

 CREATE  INDEX [IX_TT_EntryLog_ProjectID] ON [dbo].[TT_EntryLog]([ProjectID]) ON [PRIMARY]
GO

 CREATE  INDEX [IX_TT_EntryLog_TaskID] ON [dbo].[TT_EntryLog]([TaskID]) ON [PRIMARY]
GO

 CREATE  INDEX [IX_TT_EntryLog_UserID] ON [dbo].[TT_EntryLog]([UserID]) ON [PRIMARY]
GO

ALTER TABLE [dbo].[TT_ProjectMembers] ADD 
	CONSTRAINT [IX_Roles] UNIQUE  NONCLUSTERED 
	(
		[ProjectID],
		[UserID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[TT_Projects] ADD 
	CONSTRAINT [DF_Projects_CreationDate] DEFAULT (getdate()) FOR [CreationDate],
	CONSTRAINT [PK_Projects] PRIMARY KEY  NONCLUSTERED 
	(
		[ProjectID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[TT_TaskAssignee] ADD 
	CONSTRAINT [IX_TT_TaskAssignee] UNIQUE  NONCLUSTERED 
	(
		[TaskID],
		[UserID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[TT_Users] ADD 
	CONSTRAINT [PK_Users] PRIMARY KEY  NONCLUSTERED 
	(
		[UserID]
	)  ON [PRIMARY] ,
	CONSTRAINT [IX_Users] UNIQUE  NONCLUSTERED 
	(
		[UserName]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[NF_Notifications] ADD 
	CONSTRAINT [FK_NF_Notifications_TT_Projects] FOREIGN KEY 
	(
		[ProjectID]
	) REFERENCES [dbo].[TT_Projects] (
		[ProjectID]
	) ON DELETE CASCADE 
GO

ALTER TABLE [dbo].[NF_NotificationDetails] ADD 
	CONSTRAINT [FK_NF_NotificationDetails_NF_Actions] FOREIGN KEY 
	(
		[ActionID]
	) REFERENCES [dbo].[NF_Actions] (
		[ActionID]
	) ON DELETE CASCADE ,
	CONSTRAINT [FK_NF_NotificationDetails_NF_Notifications] FOREIGN KEY 
	(
		[NotificationID]
	) REFERENCES [dbo].[NF_Notifications] (
		[NotificationID]
	) ON DELETE CASCADE 
GO

ALTER TABLE [dbo].[NF_NotificationUsers] ADD 
	CONSTRAINT [FK_NF_NotificationUsers_NF_Notifications] FOREIGN KEY 
	(
		[NotificationID]
	) REFERENCES [dbo].[NF_Notifications] (
		[NotificationID]
	) ON DELETE CASCADE ,
	CONSTRAINT [FK_NF_NotificationUsers_TT_Users] FOREIGN KEY 
	(
		[UserID]
	) REFERENCES [dbo].[TT_Users] (
		[UserID]
	) ON DELETE CASCADE 
GO

ALTER TABLE [dbo].[RG_DatasourceField] ADD 
	CONSTRAINT [FK_RG_DataSourceField_RG_DataSource] FOREIGN KEY 
	(
		[DatasourceID]
	) REFERENCES [dbo].[RG_Datasource] (
		[DatasourceID]
	) ON DELETE CASCADE  ON UPDATE CASCADE 
GO

ALTER TABLE [dbo].[RG_DatasourceParam] ADD 
	CONSTRAINT [FK_RG_DataSourceParam_RG_DataSource] FOREIGN KEY 
	(
		[DatasourceID]
	) REFERENCES [dbo].[RG_Datasource] (
		[DatasourceID]
	) ON DELETE CASCADE  ON UPDATE CASCADE 
GO

ALTER TABLE [dbo].[RG_Group] ADD 
	CONSTRAINT [FK_RG_TemplateGroup_RG_Template] FOREIGN KEY 
	(
		[TemplateID]
	) REFERENCES [dbo].[RG_Template] (
		[TemplateID]
	) ON DELETE CASCADE  ON UPDATE CASCADE 
GO

ALTER TABLE [dbo].[RG_GroupField] ADD 
	CONSTRAINT [FK_RG_GroupField_RG_DatasourceField] FOREIGN KEY 
	(
		[DatasourceFieldID]
	) REFERENCES [dbo].[RG_DatasourceField] (
		[DatasourceFieldID]
	) ON DELETE CASCADE ,
	CONSTRAINT [FK_RG_GroupField_RG_Group] FOREIGN KEY 
	(
		[GroupID]
	) REFERENCES [dbo].[RG_Group] (
		[GroupID]
	) ON DELETE CASCADE  ON UPDATE CASCADE 
GO

ALTER TABLE [dbo].[RG_GroupFieldAgg] ADD 
	CONSTRAINT [FK_RG_GroupFieldAgg_RG_Group] FOREIGN KEY 
	(
		[GroupID]
	) REFERENCES [dbo].[RG_Group] (
		[GroupID]
	) ON DELETE CASCADE  ON UPDATE CASCADE ,
	CONSTRAINT [FK_RG_GroupFieldAgg_RG_TemplateField] FOREIGN KEY 
	(
		[TemplateFieldID]
	) REFERENCES [dbo].[RG_TemplateField] (
		[TemplateFieldID]
	)
GO

ALTER TABLE [dbo].[RG_Template] ADD 
	CONSTRAINT [FK_RG_Template_RG_DataSource] FOREIGN KEY 
	(
		[DatasourceID]
	) REFERENCES [dbo].[RG_Datasource] (
		[DatasourceID]
	)
GO

ALTER TABLE [dbo].[RG_TemplateField] ADD 
	CONSTRAINT [FK_RG_TemplateField_RG_DataSourceField] FOREIGN KEY 
	(
		[DatasourceFieldID]
	) REFERENCES [dbo].[RG_DatasourceField] (
		[DatasourceFieldID]
	) ON DELETE CASCADE ,
	CONSTRAINT [FK_RG_TemplateField_RG_Template] FOREIGN KEY 
	(
		[TemplateID]
	) REFERENCES [dbo].[RG_Template] (
		[TemplateID]
	) ON DELETE CASCADE  ON UPDATE CASCADE 
GO

ALTER TABLE [dbo].[TT_Categories] ADD 
	CONSTRAINT [FK_Categories_Projects] FOREIGN KEY 
	(
		[ProjectID]
	) REFERENCES [dbo].[TT_Projects] (
		[ProjectID]
	) ON DELETE CASCADE 
GO

ALTER TABLE [dbo].[TT_EntryLog] ADD 
	CONSTRAINT [FK_TT_EntryLog_TT_Projects] FOREIGN KEY 
	(
		[ProjectID]
	) REFERENCES [dbo].[TT_Projects] (
		[ProjectID]
	) ON DELETE CASCADE 
GO

ALTER TABLE [dbo].[TT_Expenses] ADD 
	CONSTRAINT [FK_TT_Expenses_TT_Projects] FOREIGN KEY 
	(
		[ProjectID]
	) REFERENCES [dbo].[TT_Projects] (
		[ProjectID]
	) ON DELETE CASCADE 
GO

ALTER TABLE [dbo].[TT_MessageBoard] ADD 
	CONSTRAINT [FK_TT_MessageBoard_TT_Projects] FOREIGN KEY 
	(
		[ProjectID]
	) REFERENCES [dbo].[TT_Projects] (
		[ProjectID]
	) ON DELETE CASCADE 
GO

ALTER TABLE [dbo].[TT_Payments] ADD 
	CONSTRAINT [FK_TT_Payments_TT_Projects] FOREIGN KEY 
	(
		[ProjectID]
	) REFERENCES [dbo].[TT_Projects] (
		[ProjectID]
	) ON DELETE CASCADE 
GO

ALTER TABLE [dbo].[TT_ProjectMembers] ADD 
	CONSTRAINT [FK_Roles_Projects] FOREIGN KEY 
	(
		[ProjectID]
	) REFERENCES [dbo].[TT_Projects] (
		[ProjectID]
	) ON DELETE CASCADE ,
	CONSTRAINT [FK_WorksOn_Users] FOREIGN KEY 
	(
		[UserID]
	) REFERENCES [dbo].[TT_Users] (
		[UserID]
	)
GO

ALTER TABLE [dbo].[TT_TaskAssignee] ADD 
	CONSTRAINT [FK_TT_TaskAssignee_TT_Tasks] FOREIGN KEY 
	(
		[TaskID]
	) REFERENCES [dbo].[TT_Tasks] (
		[TaskID]
	) ON DELETE CASCADE ,
	CONSTRAINT [FK_TT_TaskAssignee_TT_Users] FOREIGN KEY 
	(
		[UserID]
	) REFERENCES [dbo].[TT_Users] (
		[UserID]
	)
GO

ALTER TABLE [dbo].[TT_Tasks] ADD 
	CONSTRAINT [FK_TT_Tasks_TT_Categories] FOREIGN KEY 
	(
		[CategoryID]
	) REFERENCES [dbo].[TT_Categories] (
		[CategoryID]
	),
	CONSTRAINT [FK_TT_Tasks_TT_Projects] FOREIGN KEY 
	(
		[ProjectID]
	) REFERENCES [dbo].[TT_Projects] (
		[ProjectID]
	) ON DELETE CASCADE 
GO

ALTER TABLE [dbo].[TT_UserOps] ADD 
	CONSTRAINT [FK_TT_UserOps_TT_Users] FOREIGN KEY 
	(
		[UserID]
	) REFERENCES [dbo].[TT_Users] (
		[UserID]
	) ON DELETE CASCADE 
GO

ALTER TABLE [dbo].[TT_Users] ADD 
	CONSTRAINT [FK_Users_Roles] FOREIGN KEY 
	(
		[RoleID]
	) REFERENCES [dbo].[TT_Roles] (
		[RoleID]
	)
GO

ALTER TABLE [dbo].[TT_Workflow] ADD 
	CONSTRAINT [FK_TT_Workflow_TT_Users] FOREIGN KEY 
	(
		[UserID]
	) REFERENCES [dbo].[TT_Users] (
		[UserID]
	) ON DELETE CASCADE 
GO

CREATE FUNCTION dbo.ep_calcProjectAttachCount
	(
		@projectID int
	)
RETURNS int
AS 
	BEGIN
		DECLARE 
			@taskACount int,
			@projACount int
		
		SET @taskACount = 
		(
			SELECT COUNT(AttachID) 
			FROM TT_Attach att
			INNER JOIN TT_Tasks ts ON ts.TaskID = att.ParentID
			WHERE att.ParentType = 1 AND ts.ProjectID = @projectID
		)
		
		SET @projACount = 
		(
			SELECT COUNT(AttachID) 
			FROM TT_Attach att
			INNER JOIN TT_Projects pj ON pj.ProjectID = att.ParentID
			WHERE att.ParentType = 4 AND pj.ProjectID = @projectID
		)
		
	RETURN @taskACount + @projACount
	END

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

 CREATE FUNCTION dbo.ep_calcProjectMessageCount
	(
		@projectID int
	)
RETURNS int
AS
	BEGIN
		DECLARE @msgCount int
		
		SET @msgCount = 
		(
			SELECT COUNT(MessageID)
			FROM TT_MessageBoard
			WHERE ProjectID = @projectID
		)
		
	RETURN @msgCount
	END

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

 CREATE FUNCTION dbo.ep_calcProjectTaskCount
	(
		@projectID int,
		@taskType int
	)
RETURNS int
AS
	BEGIN
		DECLARE @taskCount int
		
		SET @taskCount =
		(
			SELECT 
				COUNT(TaskID)
			FROM TT_Tasks
			WHERE TaskType = @taskType AND ProjectID = @projectID
		)
		
		RETURN @taskCount
	END

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

 CREATE FUNCTION dbo.ep_getTaskAttachCount
	(
		@taskID int
	/*
	@parameter1 datatype = default value,
	@parameter2 datatype
	*/
	)
RETURNS int
AS
	BEGIN
		DECLARE 
			@taskACount int
		
		SET @taskACount = 
		(
			SELECT COUNT(AttachID) 
			FROM TT_Attach att
			INNER JOIN TT_Tasks ts ON ts.TaskID = att.ParentID
			WHERE att.ParentType = 1 AND ts.TaskID = @taskID
		)
	RETURN @taskACount
	END

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE FUNCTION dbo.ep_getTaskMessageCount
	(
		@taskID int
	)
RETURNS int
AS
	BEGIN
		DECLARE @msgCount int
		
		SET @msgCount = 
		(
			SELECT COUNT(MessageID)
			FROM TT_MessageBoard
			WHERE ParentID = @taskID AND ParentType = 1
		)
	RETURN @msgCount
	END

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

 CREATE FUNCTION dbo.ep_wflGetLastRecordedDateForTask
	(
		@taskID int	
	)
RETURNS datetime
AS
	BEGIN
		DECLARE @ld datetime
		
		SET @ld = 
		(
			SELECT TOP 1 EntryDate 
			FROM TT_Workflow 
			WHERE ObjectType=3 AND ObjectID=@taskID 
			ORDER BY EntryDate DESC
		)
		
	RETURN @ld
	END

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO


SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE VIEW dbo.vwTaskWorkflow
AS
SELECT     ts.TaskID, us.DisplayName, wfl.UserID, wfl.EntryDate, wfl.Action, wfl.CustomAction
FROM         dbo.TT_Workflow wfl INNER JOIN
                      dbo.TT_Tasks ts ON ts.TaskID = wfl.ObjectID INNER JOIN
                      dbo.TT_Users us ON us.UserID = wfl.UserID
WHERE     (wfl.ObjectType = 3)

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO


CREATE VIEW dbo.vwTasks_Lite
AS
SELECT     ts.TaskID, ts.Description, ts.ParentID, ts.ProjectID, ts.Status, ts.EstCompletionDate, ts.EstDuration, ts.CategoryID, ts.Title, ts.Billable, ts.BillType, 
                      ts.Amount, ts.StartDate, ts.PercentCompleted, ts.Priority, ts.TaskType, ts.BugType, ts.CustomData, pj.Name AS ProjectTitle, 
                      st.StatusName AS StatusName, bgt.Name AS BugTypeString, pri.Name AS PriorityName, csd.CustomerID AS CustomerID, csd.CompanyName, 
                      st.TreatAsCompleted, cat.Name AS CategoryName, ddt.TypeName AS TaskTypeName
FROM         dbo.TT_Tasks ts INNER JOIN
                      dbo.TT_Projects pj ON pj.ProjectID = ts.ProjectID LEFT OUTER JOIN
                      dbo.DD_BugTypes bgt ON bgt.Number = ts.BugType INNER JOIN
                      dbo.DD_Priorities pri ON pri.Number = ts.Priority LEFT OUTER JOIN
                      dbo.TT_CustomerDetails csd ON csd.CustomerID = pj.CustomerID INNER JOIN
                      dbo.TT_Categories cat ON cat.CategoryID = ts.CategoryID INNER JOIN
                      dbo.DD_TaskTypes ddt ON ddt.ID = ts.TaskType INNER JOIN
                      dbo.DD_Statuses st ON st.StatusType = ddt.TypeName AND st.Number = ts.Status


GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE VIEW dbo.vwProjects
AS
SELECT     pj.ProjectID, pj.Name, pj.Description, pj.EstCompletionDate, pj.EstDuration, pj.CreationDate, pj.Status, pj.BillingType,
	     pj.Amount, pj.IncludeTax, pj.TaxAmount, pj.AutoAssignConfig, pj.Priority, pj.PercentCompleted, pj.BugCategoryID, pj.ReqCategoryID, pj.CustomerID,
pri.Name AS PriorityName, st.StatusName AS StatusName, us.DisplayName AS ManagerDisplayName, cust.CompanyName, 
                      dbo.ep_calcProjectAttachCount(pj.ProjectID) AS AttachCount, dbo.ep_calcProjectTaskCount(pj.ProjectID, 1) AS TaskCount, 
                      dbo.ep_calcProjectTaskCount(pj.ProjectID, 2) AS BugCount, dbo.ep_calcProjectTaskCount(pj.ProjectID, 3) AS RequestCount, 
                      dbo.ep_calcProjectMessageCount(pj.ProjectID) AS MessageCount
FROM         dbo.TT_Projects pj INNER JOIN
                      dbo.DD_Priorities pri ON pri.Number = pj.Priority INNER JOIN
                      dbo.DD_Statuses st ON st.StatusType = 'Project' AND st.Number = pj.Status INNER JOIN
                      dbo.TT_ProjectMembers mb ON mb.ProjectID = pj.ProjectID AND mb.RoleID = 2 INNER JOIN
                      dbo.TT_Users us ON us.UserID = mb.UserID LEFT OUTER JOIN
                      dbo.TT_CustomerDetails cust ON cust.CustomerID = pj.CustomerID


GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO


CREATE VIEW dbo.vwTaskAssignee_Lite
AS
SELECT     ts.*, tsa.UserID AS AssignedToId, us.DisplayName AS AssignedToName
FROM         dbo.vwTasks_Lite ts LEFT OUTER JOIN
                      dbo.TT_TaskAssignee tsa ON tsa.TaskID = ts.TaskID LEFT OUTER JOIN
                      dbo.TT_Users us ON us.UserID = tsa.UserID


GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO


CREATE VIEW dbo.vwTasks
AS 
SELECT     ts.*, wfl1.DisplayName AS CreatedByName, wfl1.UserID AS CreatedBy, 
                      wfl2.DisplayName AS CompletedByName, wfl2.UserID AS CompletedBy, dbo.ep_getTaskAttachCount(ts.TaskID) AS AttachCount, 
                      dbo.ep_getTaskMessageCount(ts.TaskID) AS MessageCount, wfl1.EntryDate AS CreationDate, 
                      dbo.ep_wflGetLastRecordedDateForTask(ts.TaskID) AS LastStatusChangeDate
FROM         dbo.vwTasks_Lite  ts
 LEFT OUTER JOIN
                      dbo.vwTaskWorkflow wfl1 ON wfl1.TaskID = ts.TaskID AND wfl1.Action = 1 LEFT OUTER JOIN
                      dbo.vwTaskWorkflow wfl2 ON wfl2.TaskID = ts.TaskID AND wfl2.Action = 2 AND wfl2.CustomAction = 4 

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO


CREATE VIEW dbo.vwTaskAssignee
AS 
SELECT     ts.TaskID, ts.Description, ts.ParentID, ts.ProjectID, ts.Status, ts.EstCompletionDate, ts.EstDuration, ts.CategoryID, ts.Title, ts.Billable, 
	     ts.BillType, ts.Amount, ts.StartDate, ts.PercentCompleted, ts.Priority, ts.TaskType, ts.BugType, ts.CustomData,
	     ts.ProjectTitle, ts.StatusName, ts.CreatedByName, ts.CreatedBy, 
                  ts.CompletedByName, ts.CompletedBy, ts.AttachCount, 
                  ts.MessageCount, ts.CreationDate, ts.BugTypeString, ts.PriorityName, 
                  ts.LastStatusChangeDate, ts.CustomerID, ts.CompanyName, 
                  ts.TreatAsCompleted, ts.CategoryName, ts.TaskTypeName,
	     tsa.UserID AS AssignedToId, us.DisplayName AS AssignedToName
FROM         dbo.vwTasks ts LEFT OUTER JOIN
                      dbo.TT_TaskAssignee tsa ON tsa.TaskID = ts.TaskID LEFT OUTER JOIN
                      dbo.TT_Users us ON us.UserID = tsa.UserID

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

 CREATE PROCEDURE dbo.ep_utilityUpgradeD
AS

	--  
	
	RETURN 

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO


CREATE FUNCTION [dbo].[ep_requestOwnTasks]
	(
		@userId int,
		@taskType int
	)
RETURNS TABLE
AS
	RETURN 
	SELECT * FROM vwTaskAssignee WHERE ((AssignedToId = @userId) or (CreatedBy = @userId)) AND TaskType=@taskType


GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO


/* 
	users & roles 
*/

INSERT INTO TT_Roles(Name, Security, HourlyRate, Description) VALUES('Administrator', '<security><right name="ViewAllProjects" value="on" /><right name="ViewAllTasks" value="on" /><right name="ViewAllBugs" value="on" /><right name="ViewAllRequests" value="on" /><right name="ViewAllTimeEntries" value="on" /><right name="ViewOwnProjects" value="on" /><right name="ViewOwnTasks" value="on" /><right name="ViewOwnBugs" value="on" /><right name="ViewOwnRequests" value="on" /><right name="ViewOwnTimeEntries" value="on" /><right name="EditAllProjects" value="on" /><right name="EditAllTasks" value="on" /><right name="EditAllBugs" value="on" /><right name="EditAllRequests" value="on" /><right name="EditOwnProjects" value="on" /><right name="EditOwnTasks" value="on" /><right name="EditOwnBugs" value="on" /><right name="EditOwnRequests" value="on" /><right name="DeleteAllProjects" value="on" /><right name="DeleteAllTasks" value="on" /><right name="DeleteAllBugs" value="on" /><right name="DeleteAllRequests" value="on" /><right name="DeleteOwnProjects" value="on" /><right name="DeleteOwnTasks" value="on" /><right name="DeleteOwnBugs" value="on" /><right name="DeleteOwnRequests" value="on" /><right name="AddProjects" value="on" /><right name="AddTasks" value="on" /><right name="AddBugs" value="on" /><right name="AddRequests" value="on" /><right name="AddTimeEntries" value="on" /><right name="ShowCustomerReport" value="on" /><right name="ShowSummaryReport" value="on" /><right name="ShowBugReport" value="on" /><right name="ShowRequestReport" value="on" /><right name="ShowResourceReport" value="on" /><right name="ShowProjectReport" value="on" /><right name="Assign" value="on" /><right name="ManageUsers" value="on" /></security>', 0, 'built-in role')
INSERT INTO TT_Roles(Name, Security, HourlyRate, Description) VALUES('Project Manager', '<security><right name="ViewAllProjects" value="off" /><right name="ViewAllTasks" value="on" /><right name="ViewAllBugs" value="on" /><right name="ViewAllRequests" value="on" /><right name="ViewAllTimeEntries" value="on" /><right name="ViewOwnProjects" value="on" /><right name="ViewOwnTasks" value="on" /><right name="ViewOwnBugs" value="on" /><right name="ViewOwnRequests" value="on" /><right name="ViewOwnTimeEntries" value="on" /><right name="EditAllProjects" value="off" /><right name="EditAllTasks" value="on" /><right name="EditAllBugs" value="on" /><right name="EditAllRequests" value="on" /><right name="EditOwnProjects" value="on" /><right name="EditOwnTasks" value="on" /><right name="EditOwnBugs" value="on" /><right name="EditOwnRequests" value="on" /><right name="DeleteAllProjects" value="off" /><right name="DeleteAllTasks" value="on" /><right name="DeleteAllBugs" value="on" /><right name="DeleteAllRequests" value="on" /><right name="DeleteOwnProjects" value="on" /><right name="DeleteOwnTasks" value="on" /><right name="DeleteOwnBugs" value="on" /><right name="DeleteOwnRequests" value="on" /><right name="AddProjects" value="on" /><right name="AddTasks" value="on" /><right name="AddBugs" value="on" /><right name="AddRequests" value="on" /><right name="AddTimeEntries" value="on" /><right name="ShowCustomerReport" value="off" /><right name="ShowSummaryReport" value="on" /><right name="ShowBugReport" value="on" /><right name="ShowRequestReport" value="on" /><right name="ShowResourceReport" value="on" /><right name="ShowProjectReport" value="on" /><right name="Assign" value="on" /><right name="ManageUsers" value="off" /></security>', 0, 'built-in role')
INSERT INTO TT_Roles(Name, Security, HourlyRate, Description) VALUES('', '', 0, 'built-in role')
INSERT INTO TT_Roles(Name, Security, HourlyRate, Description) VALUES('Customer', '<security><right name="ViewAllProjects" value="off" /><right name="ViewAllTasks" value="off" /><right name="ViewAllBugs" value="off" /><right name="ViewAllRequests" value="off" /><right name="ViewAllTimeEntries" value="off" /><right name="ViewOwnProjects" value="on" /><right name="ViewOwnTasks" value="off" /><right name="ViewOwnBugs" value="on" /><right name="ViewOwnRequests" value="on" /><right name="ViewOwnTimeEntries" value="off" /><right name="EditAllProjects" value="off" /><right name="EditAllTasks" value="off" /><right name="EditAllBugs" value="off" /><right name="EditAllRequests" value="off" /><right name="EditOwnProjects" value="off" /><right name="EditOwnTasks" value="off" /><right name="EditOwnBugs" value="on" /><right name="EditOwnRequests" value="on" /><right name="DeleteAllProjects" value="off" /><right name="DeleteAllTasks" value="off" /><right name="DeleteAllBugs" value="off" /><right name="DeleteAllRequests" value="off" /><right name="DeleteOwnProjects" value="off" /><right name="DeleteOwnTasks" value="off" /><right name="DeleteOwnBugs" value="on" /><right name="DeleteOwnRequests" value="on" /><right name="AddProjects" value="off" /><right name="AddTasks" value="off" /><right name="AddBugs" value="on" /><right name="AddRequests" value="on" /><right name="AddTimeEntries" value="off" /><right name="ShowCustomerReport" value="on" /><right name="ShowSummaryReport" value="off" /><right name="ShowBugReport" value="off" /><right name="ShowRequestReport" value="off" /><right name="ShowResourceReport" value="off" /><right name="ShowProjectReport" value="off" /><right name="Assign" value="off" /><right name="ManageUsers" value="off" /></security>', 0, 'built-in role')
INSERT INTO TT_Roles(Name, Security, HourlyRate, Description) VALUES('Developer', '<security><right name="ViewAllProjects" value="off" /><right name="ViewAllTasks" value="off" /><right name="ViewAllBugs" value="off" /><right name="ViewAllRequests" value="off" /><right name="ViewAllTimeEntries" value="off" /><right name="ViewOwnProjects" value="on" /><right name="ViewOwnTasks" value="on" /><right name="ViewOwnBugs" value="on" /><right name="ViewOwnRequests" value="off" /><right name="ViewOwnTimeEntries" value="on" /><right name="EditAllProjects" value="off" /><right name="EditAllTasks" value="off" /><right name="EditAllBugs" value="off" /><right name="EditAllRequests" value="off" /><right name="EditOwnProjects" value="on" /><right name="EditOwnTasks" value="on" /><right name="EditOwnBugs" value="on" /><right name="EditOwnRequests" value="off" /><right name="DeleteAllProjects" value="off" /><right name="DeleteAllTasks" value="off" /><right name="DeleteAllBugs" value="off" /><right name="DeleteAllRequests" value="off" /><right name="DeleteOwnProjects" value="off" /><right name="DeleteOwnTasks" value="off" /><right name="DeleteOwnBugs" value="off" /><right name="DeleteOwnRequests" value="off" /><right name="AddProjects" value="off" /><right name="AddTasks" value="on" /><right name="AddBugs" value="on" /><right name="AddRequests" value="off" /><right name="AddTimeEntries" value="on" /><right name="ShowCustomerReport" value="off" /><right name="ShowSummaryReport" value="off" /><right name="ShowBugReport" value="off" /><right name="ShowRequestReport" value="off" /><right name="ShowResourceReport" value="off" /><right name="ShowProjectReport" value="off" /><right name="Assign" value="off" /><right name="ManageUsers" value="off" /></security>', 0, 'built-in role')
INSERT INTO TT_Roles(Name, Security, HourlyRate, Description) VALUES('QA', '<security><right name="ViewAllProjects" value="off" /><right name="ViewAllTasks" value="off" /><right name="ViewAllBugs" value="off" /><right name="ViewAllRequests" value="off" /><right name="ViewAllTimeEntries" value="off" /><right name="ViewOwnProjects" value="on" /><right name="ViewOwnTasks" value="on" /><right name="ViewOwnBugs" value="on" /><right name="ViewOwnRequests" value="off" /><right name="ViewOwnTimeEntries" value="on" /><right name="EditAllProjects" value="off" /><right name="EditAllTasks" value="off" /><right name="EditAllBugs" value="off" /><right name="EditAllRequests" value="off" /><right name="EditOwnProjects" value="off" /><right name="EditOwnTasks" value="on" /><right name="EditOwnBugs" value="on" /><right name="EditOwnRequests" value="off" /><right name="DeleteAllProjects" value="off" /><right name="DeleteAllTasks" value="off" /><right name="DeleteAllBugs" value="off" /><right name="DeleteAllRequests" value="off" /><right name="DeleteOwnProjects" value="off" /><right name="DeleteOwnTasks" value="off" /><right name="DeleteOwnBugs" value="off" /><right name="DeleteOwnRequests" value="off" /><right name="AddProjects" value="off" /><right name="AddTasks" value="on" /><right name="AddBugs" value="on" /><right name="AddRequests" value="off" /><right name="AddTimeEntries" value="on" /><right name="ShowCustomerReport" value="off" /><right name="ShowSummaryReport" value="off" /><right name="ShowBugReport" value="off" /><right name="ShowRequestReport" value="off" /><right name="ShowResourceReport" value="off" /><right name="ShowProjectReport" value="off" /><right name="Assign" value="off" /><right name="ManageUsers" value="off" /></security>', 0, 'built-in role')
INSERT INTO TT_Roles(Name, Security, HourlyRate, Description) VALUES('Supervisor', '<security><right name="ViewAllProjects" value="on" /><right name="ViewAllTasks" value="on" /><right name="ViewAllBugs" value="on" /><right name="ViewAllRequests" value="on" /><right name="ViewAllTimeEntries" value="on" /><right name="ViewOwnProjects" value="on" /><right name="ViewOwnTasks" value="on" /><right name="ViewOwnBugs" value="on" /><right name="ViewOwnRequests" value="on" /><right name="ViewOwnTimeEntries" value="on" /><right name="EditAllProjects" value="on" /><right name="EditAllTasks" value="on" /><right name="EditAllBugs" value="on" /><right name="EditAllRequests" value="on" /><right name="EditOwnProjects" value="on" /><right name="EditOwnTasks" value="on" /><right name="EditOwnBugs" value="on" /><right name="EditOwnRequests" value="on" /><right name="DeleteAllProjects" value="on" /><right name="DeleteAllTasks" value="on" /><right name="DeleteAllBugs" value="on" /><right name="DeleteAllRequests" value="on" /><right name="DeleteOwnProjects" value="on" /><right name="DeleteOwnTasks" value="on" /><right name="DeleteOwnBugs" value="on" /><right name="DeleteOwnRequests" value="on" /><right name="AddProjects" value="on" /><right name="AddTasks" value="on" /><right name="AddBugs" value="on" /><right name="AddRequests" value="on" /><right name="AddTimeEntries" value="on" /><right name="ShowCustomerReport" value="on" /><right name="ShowSummaryReport" value="on" /><right name="ShowBugReport" value="on" /><right name="ShowRequestReport" value="on" /><right name="ShowResourceReport" value="on" /><right name="ShowProjectReport" value="on" /><right name="Assign" value="on" /><right name="ManageUsers" value="off" /></security>', 0, 'built-in role')
INSERT INTO TT_Roles(Name, Security, HourlyRate, Description) VALUES ('Customer - Limited Access', '<security><right name="ViewAllProjects" value="off" /><right name="ViewAllTasks" value="off" /><right name="ViewAllBugs" value="off" /><right name="ViewAllRequests" value="off" /><right name="ViewAllTimeEntries" value="off" /><right name="ViewOwnProjects" value="on" /><right name="ViewOwnTasks" value="off" /><right name="ViewOwnBugs" value="off" /><right name="ViewOwnRequests" value="off" /><right name="ViewOwnTimeEntries" value="off" /><right name="EditAllProjects" value="off" /><right name="EditAllTasks" value="off" /><right name="EditAllBugs" value="off" /><right name="EditAllRequests" value="off" /><right name="EditOwnProjects" value="off" /><right name="EditOwnTasks" value="off" /><right name="EditOwnBugs" value="off" /><right name="EditOwnRequests" value="off" /><right name="DeleteAllProjects" value="off" /><right name="DeleteAllTasks" value="off" /><right name="DeleteAllBugs" value="off" /><right name="DeleteAllRequests" value="off" /><right name="DeleteOwnProjects" value="off" /><right name="DeleteOwnTasks" value="off" /><right name="DeleteOwnBugs" value="off" /><right name="DeleteOwnRequests" value="off" /><right name="AddProjects" value="off" /><right name="AddTasks" value="off" /><right name="AddBugs" value="off" /><right name="AddRequests" value="off" /><right name="AddTimeEntries" value="off" /><right name="ShowCustomerReport" value="off" /><right name="ShowSummaryReport" value="off" /><right name="ShowBugReport" value="off" /><right name="ShowRequestReport" value="off" /><right name="ShowResourceReport" value="off" /><right name="ShowProjectReport" value="off" /><right name="Assign" value="off" /><right name="ManageUsers" value="off" /></security>', 0, 'built-in role')
 
DELETE FROM TT_Roles WHERE RoleID=3

INSERT INTO TT_Options(EmailAccount, EmailPassword, EmailServer, FromName, FromAddress) 
	VALUES('', '', '', '', '')

-- admin account
INSERT INTO TT_Users(DisplayName, Password, UserName, RoleID, Email, Enabled, Security, HourlyRate) VALUES('Administrator', '19-A2-85-41-44-B6-3A-8F-76-17-A6-F2-25-01-9B-12','Administrator', 1, 'admin@example.com', 1, '<security><right name="ViewAllProjects" value="on" /><right name="ViewAllTasks" value="on" /><right name="ViewAllBugs" value="on" /><right name="ViewAllRequests" value="on" /><right name="ViewAllTimeEntries" value="on" /><right name="ViewOwnProjects" value="on" /><right name="ViewOwnTasks" value="on" /><right name="ViewOwnBugs" value="on" /><right name="ViewOwnRequests" value="on" /><right name="ViewOwnTimeEntries" value="on" /><right name="EditAllProjects" value="on" /><right name="EditAllTasks" value="on" /><right name="EditAllBugs" value="on" /><right name="EditAllRequests" value="on" /><right name="EditOwnProjects" value="on" /><right name="EditOwnTasks" value="on" /><right name="EditOwnBugs" value="on" /><right name="EditOwnRequests" value="on" /><right name="DeleteAllProjects" value="on" /><right name="DeleteAllTasks" value="on" /><right name="DeleteAllBugs" value="on" /><right name="DeleteAllRequests" value="on" /><right name="DeleteOwnProjects" value="on" /><right name="DeleteOwnTasks" value="on" /><right name="DeleteOwnBugs" value="on" /><right name="DeleteOwnRequests" value="on" /><right name="AddProjects" value="on" /><right name="AddTasks" value="on" /><right name="AddBugs" value="on" /><right name="AddRequests" value="on" /><right name="AddTimeEntries" value="on" /><right name="ShowCustomerReport" value="on" /><right name="ShowSummaryReport" value="on" /><right name="ShowBugReport" value="on" /><right name="ShowRequestReport" value="on" /><right name="ShowResourceReport" value="on" /><right name="ShowProjectReport" value="on" /><right name="Assign" value="on" /><right name="ManageUsers" value="on" /></security>', 0)
INSERT INTO TT_UserOps VALUES(1, 1, 1, 1, 1)

/*
	default data
*/
INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Hold',1,'Task')

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Development',2,'Task')

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Testing',3,'Task')

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Completed',4,'Task')

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Assigned',5,'Task')

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Open',1,'Bug')

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Reviewed',2,'Bug')

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Hold',3,'Bug')

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Assigned',4,'Bug')

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Fixed',5,'Bug')

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Closed',6,'Bug')

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Verified & Closed',7,'Bug')

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Submitted',1,'Request')

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Assigned',2,'Request')

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('On Hold',3,'Request')

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Completed',4,'Request')

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Cancelled',5,'Request')

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Open',1,'Project')

INSERT INTO DD_Statuses (StatusName, Number, StatusType)
VALUES ('Completed',2,'Project')

-- categories

INSERT INTO DD_Categories (Name, Abbreviation, EstDuration)
VALUES ('Development','dev',200)

INSERT INTO DD_Categories (Name, Abbreviation, EstDuration)
VALUES ('QA','qa',200)

INSERT INTO DD_Categories (Name, Abbreviation, EstDuration)
VALUES ('Troubleshooting','trbs',200)

-- bug types

INSERT INTO DD_BugTypes (Number, Name)
VALUES (1,'Interface')

INSERT INTO DD_BugTypes (Number, Name)
VALUES (2,'Misspelling')

INSERT INTO DD_BugTypes (Number, Name)
VALUES (3,'Design')

INSERT INTO DD_BugTypes (Number, Name)
VALUES (4,'Functionality')

INSERT INTO DD_BugTypes (Number, Name)
VALUES (5,'Logic')

INSERT INTO DD_BugTypes (Number, Name)
VALUES (6,'Calculation')

-- priorities
INSERT INTO DD_Priorities (Number, Name)
VALUES (1,'Urgent')

INSERT INTO DD_Priorities (Number, Name)
VALUES (2,'High')

INSERT INTO DD_Priorities (Number, Name)
VALUES (3,'Medium')

INSERT INTO DD_Priorities (Number, Name)
VALUES (4,'Low')

/*
  Report Generator data
*/

/* ------------------------------------------------------------
   FILE:         T:\402-RG.sql
   
   DESCRIPTION:  Insert scripts for the following table(s)/view(s):

     [dbo].[RG_Datasource], [dbo].[RG_DatasourceField]
   
   CREATED:      29.12.2005 16:08:13                                    
   
   ------------------------------------------------------------ */
-- BEGINNING TRANSACTION DATA
BEGIN TRANSACTION _DATA_
GO

SET NOCOUNT ON

Print 'Disabling all Constraints'
exec sp_MSforeachtable 'ALTER TABLE ? NOCHECK CONSTRAINT ALL'

Print 'Disabling all Triggers'
exec sp_MSforeachtable 'ALTER TABLE ? DISABLE TRIGGER ALL'

PRINT 'Deleting from table: [dbo].[RG_Datasource]'
DELETE FROM [dbo].[RG_Datasource]

PRINT 'Deleting from table: [dbo].[RG_DatasourceField]'
DELETE FROM [dbo].[RG_DatasourceField]

/* Insert scripts for table: [dbo].[RG_DatasourceField] */
PRINT 'Inserting rows into table: [dbo].[RG_DatasourceField]'

SET IDENTITY_INSERT [dbo].[RG_DatasourceField] ON

INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (1, 1, 'ProjectID', 'ID', 0, '', 15, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (2, 1, 'Name', 'Project Name', 2, '', 30, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (3, 1, 'Description', 'Project Description', 2, '', 30, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (4, 1, 'EstCompletionDate', 'Estimated completion date', 3, '{0:d}', 15, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (8, 1, 'CreationDate', 'Creation date', 3, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (9, 1, 'EstDuration', 'Estimated duration', 1, '', 10, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (10, 1, 'StatusName', 'Status', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (11, 1, 'PriorityName', 'Priority', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (153, 2, 'TaskID', 'ID', 0, '', 10, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (154, 2, 'Description', 'Description', 2, '', 30, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (158, 2, 'StartDate', 'Start date', 3, '{0:d}', 15, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (159, 2, 'EstCompletionDate', 'Estimated completion date', 3, '{0:d}', 15, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (160, 2, 'EstDuration', 'Estimated duration', 1, '', 15, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (162, 2, 'Title', 'Title', 2, '', 30, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (167, 2, 'ProjectName', 'Project', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (168, 2, 'StatusName', 'Status', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (169, 2, 'CategoryName', 'Category', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (170, 4, 'TaskID', 'ID', 0, '', 10, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (172, 4, 'Description', 'Description', 2, '', 30, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (175, 4, 'PriorityName', 'Priority', 2, '', 10, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (176, 4, 'StartDate', 'Opened', 3, '', 15, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (182, 4, 'ProjectName', 'Project', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (184, 4, 'BugTypeName', 'Type', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (185, 4, 'StatusName', 'Status', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (186, 5, 'TaskID', 'ID', 0, '', 10, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (188, 5, 'Description', 'Description', 2, '', 30, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (191, 5, 'StartDate', 'Submitted', 3, '', 15, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (194, 5, 'ProjectName', 'Project', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (195, 5, 'StatusName', 'Status', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (196, 6, 'EntryLogID', 'EntryLogID', 0, '', 5, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (197, 6, 'Description', 'Description', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (198, 6, 'Duration', 'Duration', 1, '', 5, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (199, 6, 'EntryDate', 'Date', 3, '{0:d}', 10, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (204, 6, 'Billable', 'Billable', 4, '', 5, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (205, 6, 'ProjectName', 'Project', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (206, 6, 'UserDisplayName', 'Entered By', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (207, 6, 'TaskTitle', 'Task', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (208, 6, 'CategoryName', 'Category', 2, '', 20, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (210, 2, 'PriorityName', 'Priority', 2, '', 10, 0)
INSERT INTO [dbo].[RG_DatasourceField] ([DatasourceFieldID], [DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) VALUES (211, 2, 'TaskTypeName', 'Task Type', 2, NULL, 10, 0)

SET IDENTITY_INSERT [dbo].[RG_DatasourceField] OFF


/* Insert scripts for table: [dbo].[RG_Datasource] */
PRINT 'Inserting rows into table: [dbo].[RG_Datasource]'

SET IDENTITY_INSERT [dbo].[RG_Datasource] ON

INSERT INTO [dbo].[RG_Datasource] ([DatasourceID], [Name], [QueryText], [InternalID]) VALUES (1, 'Projects', N'SELECT pj.*, stat.StatusName, prio.Name as PriorityName
FROM TT_Projects pj
INNER JOIN DD_Statuses as stat
ON stat.Number = pj.Status 
INNER JOIN DD_Priorities prio
ON prio.Number = pj.Priority
WHERE stat.StatusType=''Project'' AND pj.ProjectID IN ?', 'projects')
INSERT INTO [dbo].[RG_Datasource] ([DatasourceID], [Name], [QueryText], [InternalID]) VALUES (2, 'Tasks', N'SELECT ts.*, proj.Name as ProjectName, stat.StatusName, cat.Name as CategoryName, prior.Name as PriorityName,
CASE WHEN ts.TaskType = 1 THEN ''{task}'' WHEN ts.TaskType = 2 THEN ''{bug}'' ELSE ''{request}'' END as TaskTypeName
								FROM TT_Tasks ts
								INNER JOIN TT_Projects proj
								ON proj.ProjectID = ts.ProjectID
								INNER JOIN DD_Statuses stat
								ON stat.Number = ts.Status
								INNER JOIN TT_Categories cat
								ON cat.CategoryID = ts.CategoryID
								INNER JOIN DD_Priorities prior
								ON prior.Number = ts.Priority 
								WHERE stat.StatusType = CASE WHEN ts.TaskType = 1 THEN ''Task'' WHEN ts.TaskType = 2 THEN ''Bug'' ELSE ''Request'' END
								AND proj.ProjectID IN ?
								UNION ALL

SELECT ts.*, proj.Name as ProjectName, stat.StatusName, cat.Name as CategoryName, prior.Name as PriorityName,
CASE WHEN ts.TaskType = 1 THEN ''{task}'' WHEN ts.TaskType = 2 THEN ''{bug}'' ELSE ''{request}'' END as TaskType
								FROM TT_Tasks ts
								INNER JOIN TT_Projects proj
								ON proj.ProjectID = ts.ProjectID
								INNER JOIN DD_Statuses stat
								ON stat.Number = ts.Status
								INNER JOIN TT_Categories cat
								ON cat.CategoryID = ts.CategoryID
								INNER JOIN DD_Priorities prior
								ON prior.Number = ts.Priority 
								WHERE stat.StatusType = CASE WHEN ts.TaskType = 1 THEN ''Task'' WHEN ts.TaskType = 2 THEN ''Bug'' ELSE ''Request'' END
								AND proj.ProjectID IN ?
								AND EXISTS (SELECT * FROM TT_TaskAssignee ta WHERE 
								ta.TaskID = ts.TaskID
								AND ta.UserID = ?
								)', 'tasks')
INSERT INTO [dbo].[RG_Datasource] ([DatasourceID], [Name], [QueryText], [InternalID]) VALUES (4, 'Bugs', N'SELECT ts.*, proj.Name as ProjectName, bgtp.Name as BugTypeName, stat.StatusName, prior.Name as PriorityName
								FROM TT_Tasks ts
								INNER JOIN TT_Projects proj
								ON proj.ProjectID = ts.ProjectID
								INNER JOIN DD_Statuses stat
								ON stat.Number = ts.Status AND stat.StatusType = ''Bug''
								LEFT OUTER JOIN DD_BugTypes bgtp
								ON bgtp.Number = ts.BugType
								INNER JOIN DD_Priorities prior
								ON prior.Number = ts.Priority 
								WHERE ts.TaskType = 2 
								AND proj.ProjectID IN ?
								UNION ALL

SELECT ts.*, proj.Name as ProjectName, bgtp.Name as BugTypeName, stat.StatusName, prior.Name as PriorityName
								FROM TT_Tasks ts
								INNER JOIN TT_Projects proj
								ON proj.ProjectID = ts.ProjectID
								INNER JOIN DD_Statuses stat
								ON stat.Number = ts.Status AND stat.StatusType = ''Bug''
								LEFT OUTER JOIN DD_BugTypes bgtp
								ON bgtp.Number = ts.BugType
								INNER JOIN DD_Priorities prior
								ON prior.Number = ts.Priority 
								WHERE ts.TaskType = 2
								AND proj.ProjectID IN ?
								AND EXISTS (SELECT * FROM TT_TaskAssignee ta WHERE 
								ta.TaskID = ts.TaskID
								AND ta.UserID = ?
								)', 'bugs')
INSERT INTO [dbo].[RG_Datasource] ([DatasourceID], [Name], [QueryText], [InternalID]) VALUES (5, 'Requests', N'SELECT ts.*, proj.Name as ProjectName, stat.StatusName, prior.Name as PriorityName
								FROM TT_Tasks ts
								INNER JOIN TT_Projects proj
								ON proj.ProjectID = ts.ProjectID
								INNER JOIN DD_Statuses stat
								ON stat.Number = ts.Status AND stat.StatusType = ''Request''
								INNER JOIN DD_Priorities prior
								ON prior.Number = ts.Priority 
								WHERE ts.TaskType = 3 
								AND proj.ProjectID IN ?
								UNION ALL

SELECT ts.*, proj.Name as ProjectName, stat.StatusName, prior.Name as PriorityName
								FROM TT_Tasks ts
								INNER JOIN TT_Projects proj
								ON proj.ProjectID = ts.ProjectID
								INNER JOIN DD_Statuses stat
								ON stat.Number = ts.Status AND stat.StatusType = ''Request''
								INNER JOIN DD_Priorities prior
								ON prior.Number = ts.Priority 
								WHERE ts.TaskType = 3
								AND proj.ProjectID IN ?
								AND EXISTS (SELECT * FROM TT_TaskAssignee ta WHERE 
								ta.TaskID = ts.TaskID
								AND ta.UserID = ?
								)', 'requests')
INSERT INTO [dbo].[RG_Datasource] ([DatasourceID], [Name], [QueryText], [InternalID]) VALUES (6, 'Time entries', N'SELECT lg.*, proj.Name as ProjectName, us.DisplayName UserDisplayName, 
ts.Title TaskTitle, cat.Name CategoryName
FROM TT_EntryLog lg
INNER JOIN TT_Projects proj
ON proj.ProjectID = lg.ProjectID
INNER JOIN TT_Users us
ON us.UserID = lg.UserID
INNER JOIN TT_Tasks ts
ON ts.TaskID = lg.TaskID
INNER JOIN TT_Categories cat
ON cat.CategoryID = lg.CategoryID
WHERE proj.ProjectID IN ?
UNION ALL
SELECT lg.*, proj.Name as ProjectName, us.DisplayName UserDisplayName, 
ts.Title TaskTitle, cat.Name CategoryName
FROM TT_EntryLog lg
INNER JOIN TT_Projects proj
ON proj.ProjectID = lg.ProjectID
INNER JOIN TT_Users us
ON us.UserID = lg.UserID
INNER JOIN TT_Tasks ts
ON ts.TaskID = lg.TaskID
INNER JOIN TT_Categories cat
ON cat.CategoryID = lg.CategoryID
WHERE proj.ProjectID IN ? AND lg.UserID = ?', 'timeentries')

SET IDENTITY_INSERT [dbo].[RG_Datasource] OFF

SET IDENTITY_INSERT [dbo].[RG_DatasourceParam] ON

INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (1, 1, 'ProjectIDs', 'ProjectIDs',1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (2, 2, 'AllItemsProjectIDs', 'AllItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (3, 2, 'OwnItemsProjectIDs', 'OwnItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (4, 2, 'QueryUserID', 'AllItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (5, 4, 'AllItemsProjectIDs', 'AllItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (6, 4, 'OwnItemsProjectIDs', 'OwnItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (7, 4, 'QueryUserID', 'AllItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (8, 5, 'AllItemsProjectIDs', 'AllItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (9, 5, 'OwnItemsProjectIDs', 'OwnItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (10, 5, 'QueryUserID', 'AllItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (11, 6, 'AllItemsProjectIDs', 'AllItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (12, 6, 'OwnItemsProjectIDs', 'OwnItemsProjectIDs' ,1)
INSERT INTO [dbo].[RG_DatasourceParam] ([DatasourceParamID], [DatasourceID], [ParamName], [DisplayName], [Internal]) VALUES (13, 6, 'QueryUserID', 'AllItemsProjectIDs' ,1)

SET IDENTITY_INSERT [dbo].[RG_DatasourceParam] OFF
 
Print 'Enabling all Constraints'
exec sp_MSforeachtable 'ALTER TABLE ? CHECK CONSTRAINT ALL'

Print 'Enabling all Triggers'
exec sp_MSforeachtable 'ALTER TABLE ? ENABLE TRIGGER ALL'


-- COMMITTING TRANSACTION DATA
PRINT 'Script successfully completed'
COMMIT TRANSACTION _DATA_
GO

-- adding customer field
UPDATE [dbo].[RG_Datasource] SET [QueryText] = 'SELECT pj.*, stat.StatusName, prio.Name as PriorityName, 
cust.CompanyName as Customer
FROM TT_Projects pj  
INNER JOIN DD_Statuses as stat  
ON stat.Number = pj.Status   
INNER JOIN DD_Priorities prio  
ON prio.Number = pj.Priority  
LEFT OUTER JOIN TT_CustomerDetails cust
ON cust.CustomerID = pj.CustomerID
WHERE stat.StatusType=''Project''
AND pj.ProjectID IN ?' WHERE [DatasourceID] = 1
GO

INSERT INTO [dbo].[RG_DatasourceField]([DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) 
VALUES (1, 'Customer', 'Customer', 2, NULL, 20, 0)
GO

UPDATE [dbo].[RG_Datasource] SET [QueryText] = 'SELECT ts.*, proj.Name as ProjectName, stat.StatusName, cat.Name as CategoryName, prior.Name as PriorityName,
CASE WHEN ts.TaskType = 1 THEN ''{task}'' WHEN ts.TaskType = 2 THEN ''{bug}'' ELSE ''{request}'' END as TaskTypeName, cust.CompanyName as Customer
								FROM TT_Tasks ts
								INNER JOIN TT_Projects proj
								ON proj.ProjectID = ts.ProjectID
								INNER JOIN DD_Statuses stat
								ON stat.Number = ts.Status
								INNER JOIN TT_Categories cat
								ON cat.CategoryID = ts.CategoryID
								INNER JOIN DD_Priorities prior
								ON prior.Number = ts.Priority 
							  LEFT OUTER JOIN TT_CustomerDetails cust
                ON cust.CustomerID = proj.CustomerID
								WHERE stat.StatusType = CASE WHEN ts.TaskType = 1 THEN ''Task'' WHEN ts.TaskType = 2 THEN ''Bug'' ELSE ''Request'' END
								AND proj.ProjectID IN ?
								UNION ALL

SELECT ts.*, proj.Name as ProjectName, stat.StatusName, cat.Name as CategoryName, prior.Name as PriorityName,
CASE WHEN ts.TaskType = 1 THEN ''{task}'' WHEN ts.TaskType = 2 THEN ''{bug}'' ELSE ''{request}'' END as TaskType, cust.CompanyName as Customer
								FROM TT_Tasks ts
								INNER JOIN TT_Projects proj
								ON proj.ProjectID = ts.ProjectID
								INNER JOIN DD_Statuses stat
								ON stat.Number = ts.Status
								INNER JOIN TT_Categories cat
								ON cat.CategoryID = ts.CategoryID
								INNER JOIN DD_Priorities prior
								ON prior.Number = ts.Priority 
							  LEFT OUTER JOIN TT_CustomerDetails cust
                ON cust.CustomerID = proj.CustomerID
								WHERE stat.StatusType = CASE WHEN ts.TaskType = 1 THEN ''Task'' WHEN ts.TaskType = 2 THEN ''Bug'' ELSE ''Request'' END
								AND proj.ProjectID IN ?
								AND EXISTS (SELECT * FROM TT_TaskAssignee ta WHERE 
								ta.TaskID = ts.TaskID
								AND ta.UserID = ?
								)' WHERE [DatasourceID] = 2
GO

INSERT INTO [dbo].[RG_DatasourceField]([DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) 
VALUES (2, 'Customer', 'Customer', 2, NULL, 20, 0)
GO

UPDATE [dbo].[RG_Datasource] SET [QueryText] = 'SELECT ts.*, proj.Name as ProjectName, bgtp.Name as BugTypeName, stat.StatusName, prior.Name as PriorityName, cust.CompanyName as Customer
								FROM TT_Tasks ts
								INNER JOIN TT_Projects proj
								ON proj.ProjectID = ts.ProjectID
								INNER JOIN DD_Statuses stat
								ON stat.Number = ts.Status AND stat.StatusType = ''Bug''
								LEFT OUTER JOIN DD_BugTypes bgtp
								ON bgtp.Number = ts.BugType
								INNER JOIN DD_Priorities prior
								ON prior.Number = ts.Priority 
							  LEFT OUTER JOIN TT_CustomerDetails cust
                ON cust.CustomerID = proj.CustomerID
								WHERE ts.TaskType = 2 
								AND proj.ProjectID IN ?
								UNION ALL

SELECT ts.*, proj.Name as ProjectName, bgtp.Name as BugTypeName, stat.StatusName, prior.Name as PriorityName, cust.CompanyName as Customer
								FROM TT_Tasks ts
								INNER JOIN TT_Projects proj
								ON proj.ProjectID = ts.ProjectID
								INNER JOIN DD_Statuses stat
								ON stat.Number = ts.Status AND stat.StatusType = ''Bug''
								LEFT OUTER JOIN DD_BugTypes bgtp
								ON bgtp.Number = ts.BugType
								INNER JOIN DD_Priorities prior
								ON prior.Number = ts.Priority 
							  LEFT OUTER JOIN TT_CustomerDetails cust
                ON cust.CustomerID = proj.CustomerID
								WHERE ts.TaskType = 2
								AND proj.ProjectID IN ?
								AND EXISTS (SELECT * FROM TT_TaskAssignee ta WHERE 
								ta.TaskID = ts.TaskID
								AND ta.UserID = ?
								)' WHERE [DatasourceID] = 4
GO

INSERT INTO [dbo].[RG_DatasourceField]([DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) 
VALUES (4, 'Customer', 'Customer', 2, NULL, 20, 0)
GO


UPDATE [dbo].[RG_Datasource] SET [QueryText] = 'SELECT ts.*, proj.Name as ProjectName, stat.StatusName, prior.Name as PriorityName, cust.CompanyName as Customer
								FROM TT_Tasks ts
								INNER JOIN TT_Projects proj
								ON proj.ProjectID = ts.ProjectID
								INNER JOIN DD_Statuses stat
								ON stat.Number = ts.Status AND stat.StatusType = ''Request''
								INNER JOIN DD_Priorities prior
								ON prior.Number = ts.Priority 
							  LEFT OUTER JOIN TT_CustomerDetails cust
                ON cust.CustomerID = proj.CustomerID
								WHERE ts.TaskType = 3 
								AND proj.ProjectID IN ?
								UNION ALL

SELECT ts.*, proj.Name as ProjectName, stat.StatusName, prior.Name as PriorityName, cust.CompanyName as Customer
								FROM TT_Tasks ts
								INNER JOIN TT_Projects proj
								ON proj.ProjectID = ts.ProjectID
								INNER JOIN DD_Statuses stat
								ON stat.Number = ts.Status AND stat.StatusType = ''Request''
								INNER JOIN DD_Priorities prior
								ON prior.Number = ts.Priority 
							  LEFT OUTER JOIN TT_CustomerDetails cust
                ON cust.CustomerID = proj.CustomerID
								WHERE ts.TaskType = 3
								AND proj.ProjectID IN ?
								AND EXISTS (SELECT * FROM TT_TaskAssignee ta WHERE 
								ta.TaskID = ts.TaskID
								AND ta.UserID = ?
								)' WHERE [DatasourceID] = 5
GO

INSERT INTO [dbo].[RG_DatasourceField]([DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) 
VALUES (5, 'Customer', 'Customer', 2, NULL, 20, 0)
GO

UPDATE [dbo].[RG_Datasource] SET [QueryText] = 'SELECT lg.*, proj.Name as ProjectName, us.DisplayName UserDisplayName, 
ts.Title TaskTitle, cat.Name CategoryName, cust.CompanyName as Customer
FROM TT_EntryLog lg
INNER JOIN TT_Projects proj
ON proj.ProjectID = lg.ProjectID
INNER JOIN TT_Users us
ON us.UserID = lg.UserID
INNER JOIN TT_Tasks ts
ON ts.TaskID = lg.TaskID
INNER JOIN TT_Categories cat
ON cat.CategoryID = lg.CategoryID
LEFT OUTER JOIN TT_CustomerDetails cust
ON cust.CustomerID = proj.CustomerID
WHERE proj.ProjectID IN ?
UNION ALL
SELECT lg.*, proj.Name as ProjectName, us.DisplayName UserDisplayName, 
ts.Title TaskTitle, cat.Name CategoryName, cust.CompanyName as Customer
FROM TT_EntryLog lg
INNER JOIN TT_Projects proj
ON proj.ProjectID = lg.ProjectID
INNER JOIN TT_Users us
ON us.UserID = lg.UserID
INNER JOIN TT_Tasks ts
ON ts.TaskID = lg.TaskID
INNER JOIN TT_Categories cat
ON cat.CategoryID = lg.CategoryID
LEFT OUTER JOIN TT_CustomerDetails cust
ON cust.CustomerID = proj.CustomerID
WHERE proj.ProjectID IN ? AND lg.UserID = ?' WHERE [DatasourceID] = 6
GO

INSERT INTO [dbo].[RG_DatasourceField]([DatasourceID], [FieldName], [DisplayName], [Datatype], [DataFormat], [Width], [Aggregation]) 
VALUES (6, 'Customer', 'Customer', 2, NULL, 20, 0)
GO

/*
  end report generator datasource data
*/

insert into DD_TaskTypes(TypeName, ID) values('Task', 1)
insert into DD_TaskTypes(TypeName, ID) values('Bug', 2)
insert into DD_TaskTypes(TypeName, ID) values('Request', 3)
GO

UPDATE DD_Statuses SET TreatAsCompleted = 0
UPDATE DD_Statuses SET TreatAsCompleted = 1 WHERE Number = 2 AND StatusType='Project'
UPDATE DD_Statuses SET TreatAsCompleted = 1 WHERE Number = 4 AND StatusType='Task'
UPDATE DD_Statuses SET TreatAsCompleted = 1 WHERE Number = 4 AND StatusType='Request'
UPDATE DD_Statuses SET TreatAsCompleted = 1 WHERE Number = 5 AND StatusType='Bug'
UPDATE DD_Statuses SET TreatAsCompleted = 1 WHERE Number = 5 AND StatusType='Request'
UPDATE DD_Statuses SET TreatAsCompleted = 1 WHERE Number = 6 AND StatusType='Bug'
UPDATE DD_Statuses SET TreatAsCompleted = 1 WHERE Number = 7 AND StatusType='Bug'

GO

INSERT INTO NF_Actions (Operation, Target) VALUES ('Add', 'Task')
INSERT INTO NF_Actions (Operation, Target) VALUES ('Edit', 'Task')
INSERT INTO NF_Actions (Operation, Target) VALUES ('Complete', 'Task')
INSERT INTO NF_Actions (Operation, Target) VALUES ('Delete', 'Task')
INSERT INTO NF_Actions (Operation, Target) VALUES ('Add', 'Bug')
INSERT INTO NF_Actions (Operation, Target) VALUES ('Edit', 'Bug')
INSERT INTO NF_Actions (Operation, Target) VALUES ('Complete', 'Bug')
INSERT INTO NF_Actions (Operation, Target) VALUES ('Delete', 'Bug')
INSERT INTO NF_Actions (Operation, Target) VALUES ('Add', 'Request')
INSERT INTO NF_Actions (Operation, Target) VALUES ('Edit', 'Request')
INSERT INTO NF_Actions (Operation, Target) VALUES ('Complete', 'Request')
INSERT INTO NF_Actions (Operation, Target) VALUES ('Delete', 'Request')
INSERT INTO NF_Actions (Operation, Target) VALUES ('Add', 'Attachment')
INSERT INTO NF_Actions (Operation, Target) VALUES ('Delete', 'Attachment')
INSERT INTO NF_Actions (Operation, Target) VALUES ('Add', 'Message')
INSERT INTO NF_Actions (Operation, Target) VALUES ('Edit', 'Message')
INSERT INTO NF_Actions (Operation, Target) VALUES ('Delete', 'Message')
INSERT INTO NF_Actions (Operation, Target) VALUES ('Assign', 'Task')
INSERT INTO NF_Actions (Operation, Target) VALUES ('Assign', 'Bug')
INSERT INTO NF_Actions (Operation, Target) VALUES ('Assign', 'Request')
GO

INSERT INTO TT_Version(Major,Minor,Build,MinorBuild) VALUES (4,0,16,1)